@@ -2,7 +2,7 @@
 //                               AppGSpiceUI.cpp                              *
 //                              -----------------                             *
 //  Started     : 15/08/2003                                                  *
-//  Last Update : 20/02/2008                                                  *
+//  Last Update : 22/10/2008                                                  *
 //  Copyright   : (C) 2003 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -63,16 +63,12 @@ AppGSpiceUI::~AppGSpiceUI( )
 
 bool  AppGSpiceUI::OnInit( void )
 {
-  wxString  os1;
-
   // Set the command line and process it
   if( ! m_oCmdLnPcr.bSetCmdLine( argc, argv ) ) return( FALSE );
   if( ! m_oCmdLnPcr.bProcArgs( ) )              return( FALSE );
 
   // Create the GUI
   m_poFrmMain = new FrmMain( this );
-  m_poFrmMain->Initialize( );
-  m_poFrmMain->m_oFileTsks.Initialize( );
   m_poFrmMain->Show( TRUE );
   SetTopWindow( m_poFrmMain );
 
@@ -94,7 +90,7 @@ bool  AppGSpiceUI::OnInit( void )
   }
 
   return( 0 );
-} */
+} // */
 
 //*****************************************************************************
 // wxWindows calls wxApp::OnExit( ) on application termination.
