@@ -2,7 +2,7 @@
 //                                CmdLinePcr.cpp                              *
 //                               ----------------                             *
 //  Started     : 22/02/2005                                                  *
-//  Last Update : 22/02/2008                                                  *
+//  Last Update : 12/10/2009                                                  *
 //  Copyright   : (C) 2005 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -39,11 +39,11 @@ CmdLinePcr::~CmdLinePcr( )
 //*****************************************************************************
 // Process command line option -a : analysis page specifier.
 //
-// Argument List:
+// Argument List :
 //   piArg - A pointer to the current command line argument
 //           (incremented as part of processing)
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -66,7 +66,7 @@ bool  CmdLinePcr::bProcOption_a( int * piArg )
   else if( osArg == wxT("DC") ) ;
   else if( osArg == wxT("AC") ) ;
   else if( osArg == wxT("TR") ) ;
-//else if( osArg == wxT("FO") ) ;
+  else if( osArg == wxT("FO") ) ;
 //else if( osArg == wxT("DI") ) ;
 //else if( osArg == wxT("NO") ) ;
 //else if( osArg == wxT("PZ") ) ;
@@ -85,14 +85,41 @@ bool  CmdLinePcr::bProcOption_a( int * piArg )
 }
 
 //*****************************************************************************
-// Process command line option -g : Guile procedure used when importing
-//                                  schematic file.
+// Process command line option -c : Rebuild/clean the configuration file.
 //
-// Argument List:
+// Note : This function must be called twice to actually rebuild/clean the
+//        configuration file.
+//
+// Argument List :
 //   piArg - A pointer to the current command line argument
 //           (incremented as part of processing)
 //
-// Return Values:
+// Return Values :
+//   TRUE  - Success
+//   FALSE - Failure
+
+bool  CmdLinePcr::bProcOption_c( int * piArg )
+{
+  // Signify that the configuration file needs to be rebuilt/cleaned
+  if( ! m_bCleanCfgFile )
+  {
+    m_bCleanCfgFile = TRUE;
+    return( TRUE );
+  }
+
+
+  return( TRUE );
+}
+
+//*****************************************************************************
+// Process command line option -g : Guile procedure used when importing
+//                                  schematic file.
+//
+// Argument List :
+//   piArg - A pointer to the current command line argument
+//           (incremented as part of processing)
+//
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -101,9 +128,6 @@ bool  CmdLinePcr::bProcOption_g( int * piArg )
   PrcGNetList  oGNetList;
   wxString     osArg;
 
-  // Increment argument pointer
-  ( *piArg )++;
-
   // Check that there are more arguments and that the next is not an option
   osArg = m_ppsArgV[ *piArg ];
   if( *piArg<(m_iArgC-1) && !osArg.StartsWith( wxT("-") ) )
@@ -121,7 +145,12 @@ bool  CmdLinePcr::bProcOption_g( int * piArg )
         return( FALSE );
       }
     }
+
+    // Increment argument pointer
+    ( *piArg )++;
   }
+  else // Use the default value
+    m_osGuileProc = wxT("spice-sdb");
 
   return( TRUE );
 }
@@ -129,11 +158,11 @@ bool  CmdLinePcr::bProcOption_g( int * piArg )
 //*****************************************************************************
 // Process command line option -h : display usage and exit.
 //
-// Argument List:
+// Argument List :
 //   piArg - A pointer to the current command line argument
 //           (incremented as part of processing)
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -147,11 +176,11 @@ bool  CmdLinePcr::bProcOption_h( int * piArg )
 //*****************************************************************************
 // Process command line option -r : specify a configuration file.
 //
-// Argument List:
+// Argument List :
 //   piArg - A pointer to the current command line argument
 //           (incremented as part of processing)
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -190,11 +219,11 @@ bool  CmdLinePcr::bProcOption_r( int * piArg )
 //*****************************************************************************
 // Process command line option -s : simulator engine specifier.
 //
-// Argument List:
+// Argument List :
 //   piArg - A pointer to the current command line argument
 //           (incremented as part of processing)
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -213,10 +242,8 @@ bool  CmdLinePcr::bProcOption_s( int * piArg )
   osArg = m_ppsArgV[ *piArg ];
   osArg.MakeUpper( );
 
-  if(      wxString( wxT("GNUCAP") ) .StartsWith( osArg ) )
-    osArg = wxT("GNUCAP");
-  else if( wxString( wxT("NGSPICE") ).StartsWith( osArg ) )
-    osArg = wxT("NGSPICE");
+  if(      wxString( wxT("GNUCAP") ) .StartsWith( osArg ) ) osArg = CLP_GNUCAP;
+  else if( wxString( wxT("NGSPICE") ).StartsWith( osArg ) ) osArg = CLP_NGSPICE;
   else
   {
     std::cout << "Invalid simulator engine specifier : "
@@ -232,11 +259,11 @@ bool  CmdLinePcr::bProcOption_s( int * piArg )
 //*****************************************************************************
 // Process command line option -v : display app. version and exit.
 //
-// Argument List:
+// Argument List :
 //   piArg - A pointer to the current command line argument
 //           (incremented as part of processing)
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -253,11 +280,11 @@ bool  CmdLinePcr::bProcOption_v( int * piArg )
 //*****************************************************************************
 // Process command line option -w : waveform viewer specifier.
 //
-// Argument List:
+// Argument List :
 //   piArg - A pointer to the current command line argument
 //           (incremented as part of processing)
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -276,10 +303,8 @@ bool  CmdLinePcr::bProcOption_w( int * piArg )
   osArg = m_ppsArgV[ *piArg ];
   osArg.MakeUpper( );
 
-  if(      wxString( wxT("GWAVE") ).StartsWith( osArg ) )
-    osArg = wxT("GWAVE");
-  else if( wxString( wxT("GAW") )  .StartsWith( osArg ) )
-    osArg = wxT("GAW");
+  if(      wxString( wxT("GWAVE") ).StartsWith( osArg ) ) osArg = CLP_GWAVE;
+  else if( wxString( wxT("GAW") )  .StartsWith( osArg ) ) osArg = CLP_GAW;
   else
   {
     std::cout << "Invalid waveform viewer specifier : "
@@ -295,11 +320,11 @@ bool  CmdLinePcr::bProcOption_w( int * piArg )
 //*****************************************************************************
 // Process schematic file name command line argument/s.
 //
-// Argument List:
+// Argument List :
 //   piArg - A pointer to the current command line argument
 //           (incremented as part of processing)
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -342,13 +367,13 @@ bool  CmdLinePcr::bProcSchems( int * piArg )
 }
 
 //*****************************************************************************
-// Process net list file name command line argument.
+// Process netlist file name command line argument.
 //
-// Argument List:
+// Argument List :
 //   piArg - A pointer to the current command line argument
 //           (incremented as part of processing)
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -360,7 +385,7 @@ bool  CmdLinePcr::bProcNetList( int * piArg )
   // Check that there are enough arguments
   if( *piArg >= m_iArgC )
   {
-    std::cout << "Missing net list file name.\n";
+    std::cout << "Missing netlist file name.\n";
     return( FALSE );
   }
 
@@ -369,13 +394,13 @@ bool  CmdLinePcr::bProcNetList( int * piArg )
   if( ! ofn1.IsOk( ) )
   {
     os1 = m_ppsArgV[ *piArg ];
-    std::cout << "Invalid net list file name : " << os1.mb_str( ) << '\n';
+    std::cout << "Invalid netlist file name : " << os1.mb_str( ) << '\n';
     return( FALSE );
   }
   if( ! ofn1.FileExists( ) )
   {
     os1 = m_ppsArgV[ *piArg ];
-    std::cout << "Net list file doesn't exist : " << os1.mb_str( ) << '\n';
+    std::cout << "Netlist file doesn't exist : " << os1.mb_str( ) << '\n';
     return( FALSE );
   }
   if( ofn1.IsRelative( ) ) ofn1.MakeAbsolute( );
@@ -396,22 +421,29 @@ void  CmdLinePcr::Usage( void )
 
   os2 = wxString( m_ppsArgV[ 0 ] ).AfterLast( wxT('/') );
 
-  os1 << wxT("\nUsage : ") << os2 << wxT(" [-OPTION [ARG]] [FILE/S]\n")
-      << wxT("Analyse a circuit using a SPICE electronic circuit simulation.\n")
-      << wxT("Options :\n")
-      << wxT("  -h          : Print usage (this message).\n")
-      << wxT("  -v          : Print version information.\n")
-      << wxT("  -r <RCFILE> : Specify a configuration file.\n")
-      << wxT("                  <RCFILE> = ~/.gspiceui.conf (default))\n")
-      << wxT("  -s <SIM>    : Specify the simulation engine to be used.\n")
-      << wxT("                  <SIM> = gnucap (default) or ngspice\n")
-      << wxT("  -a <ANA>    : Specify the analysis page to be displayed.\n")
-      << wxT("                  <ANA> = OP, DC (default), AC, TR, FO, DI, NO, PZ, SE or TF\n")
-      << wxT("  -g [<PROC>] : Guile procedure to import a schematic file using GNetList.\n")
-      << wxT("                  <PROC> = spice-sdb (default), PCB, protelII, verilog, etc.\n")
-      << wxT("  -w <VIEWER> : Specify the waveform viewer to be used.\n")
-      << wxT("                  <VIEWER> = gwave (default) or gaw\n")
-      << wxT("  [FILE/S]    : Load a circuit description file or import schematic file/s.\n\n");
+  os1 << wxT("\n")
+      << wxT("Analyse a electronic circuit using a GUI to a numerical simulation engine\n")
+      << wxT("\n")
+      << wxT("USAGE   : ") << os2 << wxT(" [-OPTION [ARG]] [FILE/S]\n")
+      << wxT("\n")
+      << wxT("OPTIONS : -h        : Print usage (this message)\n")
+      << wxT("          -v        : Print version information\n")
+      << wxT("          -r RCFILE : Specify a configuration file\n")
+      << wxT("                      RCFILE = ~/.gspiceui.conf (default)\n")
+      << wxT("          -c        : Rebuild/clean the configuration file\n")
+      << wxT("          -s SIMENG : Specify the simulation engine to be used\n")
+      << wxT("                      SIMENG = gnucap (default) or ngspice\n")
+      << wxT("          -a ANA    : Specify the analysis page to be displayed\n")
+      << wxT("                      ANA    = op, dc (default), ac, tr, fo, di, no, pz, se or tf\n")
+      << wxT("          -g [PROC] : Guile procedure to import a schematic file using gNetList\n")
+      << wxT("                      PROC   = spice-sdb (default), pcb, protelii, verilog, etc.\n")
+      << wxT("          -w VIEWER : Specify the waveform viewer to be used\n")
+      << wxT("                      VIEWER = gwave (default) or gaw\n")
+      << wxT("\n")
+      << wxT("ARGS    : FILE/S    : Import schematic file/s or load a circuit description file\n")
+      << wxT("\n")
+      << wxT("NOTES   : Option -s must come before -a if both are specified\n")
+      << wxT("\n");
 
   std::cout << os1.mb_str( );
 }
@@ -435,71 +467,115 @@ void  CmdLinePcr::Version( void )
 
 void  CmdLinePcr::SetConfig( void )
 {
-  wxConfig * poConfig;
+  wxConfig * poCfg;
   wxString   os1;
-  size_t     szt1;
+  int        i1;
 
   // Create the global configuration object
   if( ! m_osConfigFile.IsEmpty( ) )
        os1 = rosGetConfigFile( );
   else os1 << wxT('.') << wxString( m_ppsArgV[ 0 ] ).AfterLast( wxT('/') )
            << wxT(".conf");
-  poConfig = new wxConfig( wxEmptyString, wxEmptyString, os1 );
-  wxConfig::Set( poConfig );
-  poConfig->SetRecordDefaults( );
+  poCfg = new wxConfig( wxEmptyString, wxEmptyString, os1 );
+  wxConfig::Set( poCfg );
+  poCfg->SetRecordDefaults( TRUE );
 
   // Set the simulation engine type
   if( ! m_osSimrType.IsEmpty( ) )
   {
-    poConfig->SetPath( wxT("/Spice") );
-    poConfig->Write( wxT("Engine"), m_osSimrType );
+    poCfg->SetPath( wxT("/Simulator") );
+    poCfg->Write( wxT("Engine"), m_osSimrType );
   }
 
   // Set the analysis type
   if( ! m_osAnaType.IsEmpty( ) )
   {
-    poConfig->SetPath( wxT("/Spice") );
-    poConfig->Write( wxT("Analysis"), m_osAnaType );
+    poCfg->SetPath( wxT("/Simulator") );
+    poCfg->Write( wxT("Analysis"), m_osAnaType );
   }
 
   // Set the Guile procedure to be used by GNetList
   if( ! m_osGuileProc.IsEmpty( ) )
   {
-    poConfig->SetPath( wxT("/gnetlist") );
-    poConfig->Write( wxT("GuileProc"), m_osGuileProc );
+    poCfg->SetPath( wxT("/gNetList") );
+    poCfg->Write( wxT("GuileProc"), m_osGuileProc );
   }
 
   // Set the waveform viewer type
   if( ! m_osViewer.IsEmpty( ) )
   {
-    poConfig->SetPath( wxT("/Viewer") );
-    poConfig->Write( wxT("Name"), m_osViewer );
+    poCfg->SetPath( wxT("/Viewer") );
+    poCfg->Write( wxT("Name"), m_osViewer );
   }
 
-  // Set the net list file name
+  // Set the netlist file name
   if( ! m_osNetLstFile.IsEmpty( ) )
   {
-    poConfig->SetPath( wxT("/Files") );
-    poConfig->Write( wxT("NetList"), m_osNetLstFile );
+    poCfg->SetPath( wxT("/Files") );
+    poCfg->Write( wxT("NetList"), m_osNetLstFile );
   }
 
   // Set the schematic file name/s
   if( ! m_oasSchemFiles.IsEmpty( ) )
   {
-    poConfig->SetPath( wxT("/Files") );
-    for( szt1=0, os1.Empty( ); szt1<m_oasSchemFiles.GetCount( ); szt1++ )
-      os1 << m_oasSchemFiles.Item( szt1 ) << wxT(' ');
-    poConfig->Write( wxT("Schematics"), os1 );
+    poCfg->SetPath( wxT("/Files") );
+    for( i1=0, os1.Empty( ); i1<(int)m_oasSchemFiles.GetCount( ); i1++ )
+      os1 << m_oasSchemFiles.Item( i1 ) << wxT(' ');
+    poCfg->Write( wxT("Schematics"), os1 );
   }
 
   // Write any changes to file
-  poConfig->Flush( );
+  poCfg->Flush( );
+}
+
+//*****************************************************************************
+// Rebuild/clean the configuration file.
+
+void  CmdLinePcr::CleanCfgFile( void )
+{
+  wxConfig * poCfg;
+  wxString   os1;
+  long       li1;
+  uint       ui1;
+  bool       b1;
+
+  // Get a pointer to the configuration object
+  poCfg = (wxConfig *) wxConfig::Get( );
+
+  // Record the number of groups
+  ui1 = poCfg->GetNumberOfGroups( );
+
+  // Look for any superceded groups
+  for( b1=poCfg->GetFirstGroup(os1,li1); b1; b1=poCfg->GetNextGroup(os1,li1) )
+  {
+    if(      os1 == wxT("Help")        ) continue;
+    else if( os1 == wxT("Main")        ) continue;
+    else if( os1 == wxT("Simulator")   ) continue;
+    else if( os1 == wxT("gNetList")    ) continue;
+    else if( os1 == wxT("Files")       ) continue;
+    else if( os1 == wxT("Directories") ) continue;
+    else if( os1 == wxT("Viewer")      ) continue;
+    else if( os1 == wxT("GNU-Cap")     ) continue;
+
+    poCfg->DeleteGroup( os1 );
+  }
+
+  // Write any changes to file
+  poCfg->Flush( );
+
+  // Display message to the user
+  ui1 -= poCfg->GetNumberOfGroups( );
+  os1.Empty( );
+  os1 << wxT("Rebuild/clean configuration file : ");
+  if( ui1 > 0 ) os1 << ui1 << wxT(" unused group/s found & deleted\n");
+  else          os1 << wxT("nothing to be done\n");
+  std::cout << os1.mb_str( );
 }
 
 //*****************************************************************************
 // Clear the object attributes.
 //
-// Return Arguments:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -512,6 +588,7 @@ bool  CmdLinePcr::bClear( void )
   m_osConfigFile .Empty( );
   m_osNetLstFile .Empty( );
   m_oasSchemFiles.Empty( );
+  m_bCleanCfgFile = FALSE;
 
   return( TRUE );
 }
@@ -519,11 +596,11 @@ bool  CmdLinePcr::bClear( void )
 //*****************************************************************************
 // Set the command line to be processed.
 //
-// Arguments:
+// Argument List :
 //   iArgV   - The argment count
 //   ppsArgV - The string array of argument fields
 //
-// Return Arguments:
+// Return Values:
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -542,7 +619,7 @@ bool  CmdLinePcr::bSetCmdLine( int iArgC, wxChar ** ppsArgV )
 //*****************************************************************************
 // Process any command line arguments past to the application at start-up.
 //
-// Return Arguments:
+// Return Values :
 //   TRUE  - Success (continue  application execution)
 //   FALSE - Failure (terminate application execution)
 
@@ -575,6 +652,10 @@ bool  CmdLinePcr::bProcArgs( void )
     { // Specify a configuration file
       if( ! bProcOption_r( &iArg ) ) return( FALSE );
     }
+    else if( osArg == wxT("-c") )
+    { // Rebuild/clean the configuration file
+      if( ! bProcOption_c( &iArg ) ) return( FALSE );
+    }
     else if( osArg == wxT("-s") )
     { // Process simulation engine specifier
       if( ! bProcOption_s( &iArg ) ) return( FALSE );
@@ -618,13 +699,19 @@ bool  CmdLinePcr::bProcArgs( void )
     for( osArg=m_ppsArgV[ iArg ]; iArg<m_iArgC; osArg=m_ppsArgV[ ++iArg ] )
       os1 << wxT(' ') << osArg;
     std::cout << os1.mb_str( ) << '\n';
-
     return( FALSE );
   }
 
-  // Ammend the configuration file
+  // Update the configuration file
   SetConfig( );
 
+  // Rebuild/clean the configuration file if requested
+  if( m_bCleanCfgFile )
+  {
+    CleanCfgFile( );
+    return( FALSE );
+  }
+
   // All's well so display the system banner on the console
   Version( );
 
