@@ -3,7 +3,7 @@
 //                               ----------------                             *
 //  Description : This class does the command line processing.                *
 //  Started     : 22/02/2005                                                  *
-//  Last Update : 22/02/2008                                                  *
+//  Last Update : 12/10/2009                                                  *
 //  Copyright   : (C) 2005 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -38,15 +38,20 @@
 
 // Local constant declarations
 
+#define CLP_NGSPICE  wxT("NGSPICE")
+#define CLP_GNUCAP   wxT("GNUCAP")
+
+#define CLP_GWAVE    wxT("GWAVE")
+#define CLP_GAW      wxT("GAW")
 
 //*****************************************************************************
 
 class CmdLinePcr : wxCmdLineParser
 {
-  private:
+  private :
 
-    int           m_iArgC;
-    wxChar **     m_ppsArgV;
+    int            m_iArgC;
+    wxChar **      m_ppsArgV;
 
     wxString       m_osSimrType;
     wxString       m_osAnaType;
@@ -55,8 +60,10 @@ class CmdLinePcr : wxCmdLineParser
     wxString       m_osConfigFile;
     wxString       m_osNetLstFile;
     wxArrayString  m_oasSchemFiles;
+    bool           m_bCleanCfgFile;
 
     bool  bProcOption_a( int * piArg );  // Analysis page specifier
+    bool  bProcOption_c( int * piArg );  // Rebuild/clean configuration file
     bool  bProcOption_g( int * piArg );  // Specify Guile procedure for import
     bool  bProcOption_h( int * piArg );  // Display usage and exit
     bool  bProcOption_r( int * piArg );  // Specify a configuration file
@@ -64,17 +71,18 @@ class CmdLinePcr : wxCmdLineParser
     bool  bProcOption_v( int * piArg );  // Display app. version and exit
     bool  bProcOption_w( int * piArg );  // Specify the waveform viewer to use
     bool  bProcSchems  ( int * piArg );  // Schematic file name/s
-    bool  bProcNetList ( int * piArg );  // Net list file name
+    bool  bProcNetList ( int * piArg );  // Netlist file name
 
     void  Usage( void );
     void  Version( void );
 
     void  SetConfig( void );
+    void  CleanCfgFile( void );
 
-  public:
+  public :
 
     CmdLinePcr( void );
-    ~CmdLinePcr( );
+   ~CmdLinePcr( );
 
     bool  bClear( void );
     bool  bSetCmdLine( int iArgC, wxChar ** ppsArgV );
