@@ -4,7 +4,7 @@
 //  Description : This header file mostly contains enumerated type            *
 //                definitions which may be used anywhere in the application.  *
 //  Started     : 06/09/2007                                                  *
-//  Last Update : 23/01/2008                                                  *
+//  Last Update : 19/08/2009                                                  *
 //  Copyright   : (C) 2007 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -21,22 +21,24 @@
 #ifndef TYPEDEFS_HPP
 #define TYPEDEFS_HPP
 
+// wxWindows Includes
+
+#include <wx/wx.h>
 #include <wx/filename.h>
-#include <wx/dynarray.h>
 
 //*****************************************************************************
 // Fonts
 
-#define FONT_NORM   wxFont( 9, wxFONTFAMILY_SWISS,  wxFONTSTYLE_NORMAL, wxFONTWEIGHT_LIGHT )
-#define FONT_BOLD   wxFont( 9, wxFONTFAMILY_SWISS,  wxFONTSTYLE_NORMAL, wxFONTWEIGHT_BOLD  )
-#define FONT_SLANT  wxFont( 9, wxFONTFAMILY_SWISS,  wxFONTSTYLE_SLANT,  wxFONTWEIGHT_LIGHT )
-#define FONT_MONO   wxFont( 8, wxFONTFAMILY_MODERN, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_LIGHT )
+#define FONT_NORM   wxFont( 9, wxFONTFAMILY_SWISS,  wxFONTSTYLE_NORMAL, wxFONTWEIGHT_NORMAL )
+#define FONT_BOLD   wxFont( 9, wxFONTFAMILY_SWISS,  wxFONTSTYLE_NORMAL, wxFONTWEIGHT_BOLD   )
+#define FONT_SLANT  wxFont( 9, wxFONTFAMILY_SWISS,  wxFONTSTYLE_SLANT,  wxFONTWEIGHT_LIGHT  )
+#define FONT_MONO   wxFont( 8, wxFONTFAMILY_MODERN, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_NORMAL )
 
 //*****************************************************************************
 // Enumerated types
 
 // Enumerated type for the various simulator engine types
-enum eSimrType
+enum  eSimrType
 {
   eSIMR_GNUCAP,   // GNU-Cap
   eSIMR_NGSPICE,  // NG-Spice
@@ -48,7 +50,7 @@ enum eSimrType
 };
 
 // Enumerated type for the various waveform viewers types
-enum eViewType
+enum  eViewType
 {
   eVIEW_GWAVE,  // GWave
   eVIEW_GAW,    // Gaw
@@ -59,28 +61,86 @@ enum eViewType
   eVIEW_LST = eVIEW_GAW
 };
 
-// Enumerated type for the various analyses types which may be performed
-enum eAnaType
+// Enumerated type for the various command types which may be performed
+enum  eCmdType
 {
-  eANA_OP = 0,  // Quiescent operating point analysis
-  eANA_DC,      // DC analysis
-  eANA_AC,      // AC analysis
-  eANA_TR,      // Transient analysis
-  eANA_FO,      // Fourier analysis
-  eANA_DI,      // Distortion analysis
-  eANA_NO,      // Noise analysis
-  eANA_PZ,      // Pole-zero analysis
-  eANA_SE,      // Sensitivity analysis
-  eANA_TF,      // Transfer function analysis
+  eCMD_OP = 0,  // Quiescent operating point analysis
+  eCMD_DC,      // DC analysis
+  eCMD_AC,      // AC analysis
+  eCMD_TR,      // Transient analysis
+  eCMD_FO,      // Fourier analysis
+  eCMD_DI,      // Distortion analysis
+  eCMD_NO,      // Noise analysis
+  eCMD_PZ,      // Pole-zero analysis
+  eCMD_SE,      // Sensitivity analysis
+  eCMD_TF,      // Transfer function analysis
 
-  eANA_NONE,    // Analysis type not set
+  eCMD_OPT,     // OPTIONS command
+  eCMD_IC,      // Initial conditions command
+  eCMD_PR,      // PRINT command
+  eCMD_GEN,     // GENERATOR command (GNU-Cap only)
 
-  eANA_FST = eANA_OP,
-  eANA_LST = eANA_TF
+  eCMD_NONE,    // Analysis type not set
+
+  eCMD_FST = eCMD_OP,
+  eCMD_LST = eCMD_GEN,
+
+  eCMD_ANA_FST = eCMD_OP,
+  eCMD_ANA_LST = eCMD_TF
+};
+
+// Enumerated type for the various components
+enum  eCpntType
+{
+  eCPNT_CAP,      // Capacitor
+  eCPNT_RES,      // Resistor
+  eCPNT_ADM,      // Admittance
+  eCPNT_IND,      // Inductor
+  eCPNT_DIODE,    // Diode
+  eCPNT_BJT,      // Bipolar Junction Transistor
+  eCPNT_JFET,     // Junction Field-Effect Transistor
+  eCPNT_MOS,      // Metal-Oxide Semiconductor Field-Effect Transistor
+  eCPNT_VCVS,     // Voltage Controlled Voltage Source
+  eCPNT_CCCS,     // Current Controlled Current Source
+  eCPNT_VCCS,     // Voltage Controlled Current Source
+  eCPNT_CCVS,     // Current Controlled Voltage Source
+  eCPNT_CIND,     // Coupled (Mutual) Inductors
+  eCPNT_TLINE,    // Transmission Line
+  eCPNT_LOGIC,    // Logic Device
+  eCPNT_ICS,      // Independent Current Source
+  eCPNT_IVS,      // Independent Voltage Source
+  eCPNT_CCSW,     // Current Controlled Switch
+  eCPNT_VCSW,     // Voltage Controlled Switch
+  eCPNT_SUBCKT,   // Sub-circuit
+
+  eCPNT_NONE,     // None type selected
+
+  eCPNT_FST = eCPNT_CAP,
+  eCPNT_LST = eCPNT_SUBCKT
+};
+
+// Enumerated type for the various types of units
+enum eUnitsType
+{
+  eUNITS_CAP,      // Capacitance
+  eUNITS_IND,      // Inductance
+  eUNITS_RES,      // Resistance
+  eUNITS_VOLT,     // Voltage
+  eUNITS_CURR,     // Current
+  eUNITS_TIME,     // Time
+  eUNITS_FREQ,     // Frequency
+  eUNITS_PHASE,    // Phase
+  eUNITS_TEMP,     // Temperature
+  eUNITS_SCLR,     // Scalar
+
+  eUNITS_NONE,     // No units specified
+
+  eUNITS_FST = eUNITS_CAP,
+  eUNITS_LST = eUNITS_SCLR
 };
 
 // Enumerated type for the various parameters which may be determined by analysis
-enum eParType
+enum  eParType
 {
   ePAR_VLT = 0,  // Node or component voltage
   ePAR_CUR,      // Node or component current
@@ -94,7 +154,7 @@ enum eParType
 };
 
 // Enumerated type for the various sub-parameters which may be determined (AC analysis only)
-enum eCpxType
+enum  eCpxType
 {
   eCPX_MAG = 0,  // Magnitude      of the complex node or component parameter
   eCPX_PHASE,    // Phase          of the complex node or component parameter
@@ -135,9 +195,22 @@ enum  eInitCType
   eINITC_LST = eINITC_COLD
 };
 
-//*****************************************************************************
+// Enumerated type for the temporary file management strategy
+enum eTypeTmpFileMgt
+{
+  eTFMS_DELETE=0,
+  eTFMS_PROMPT,
+  eTFMS_KEEP,
+  eTFMS_NONE,
 
-WX_DECLARE_OBJARRAY( wxFileName, ArrayFileName );
+  eTFMS_FST = eTFMS_DELETE,
+  eTFMS_LST = eTFMS_KEEP
+};
+
+//*****************************************************************************
+// Define new array types
+
+WX_DECLARE_OBJARRAY( wxFileName, ArrayFileName  );
 
 //*****************************************************************************
 
