@@ -1,13 +1,13 @@
 //*****************************************************************************
 //                                 CmdBase.hpp                                *
 //                                -------------                               *
-//  Description : This is the base class for all command classes. It has some *
-//                characteristics of structure in that some attributes have   *
-//                public access; this simplifies the classes interface.       *
-//  Started     : 31/08/2006                                                  *
-//  Last Update : 30/01/2008                                                  *
-//  Copyright   : (C) 2006 by M.S.Waters                                      *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Description : This is the base class for all command classes. It has some  *
+//               characteristics of structure in that some attributes have    *
+//               public access; this simplifies the classes interface.        *
+// Started     : 31/08/2006                                                   *
+// Last Update : 16/09/2009                                                   *
+// Copyright   : (C) 2006 by M.S.Waters                                       *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -34,6 +34,7 @@ using  namespace  std;
 
 // Application Includes
 
+#include "TypeDefs.hpp"
 
 // Local Constant Declarations
 
@@ -44,22 +45,36 @@ struct CmdBase : public wxString
 {
   protected :
 
-    bool  m_bIsOk;
+    eSimrType  m_eSimEng;
+    eCmdType   m_eCmdType;
+
+    wxString   m_osErrMsg;
+
+    virtual  bool  bValidate( void );
 
   public :
 
-    wxString  m_osName;
-
               CmdBase( void );
     virtual  ~CmdBase( );
 
-    bool  bClear( void );
-    bool  bIsOk( void ) { return( m_bIsOk ); }
+    virtual  bool  bClear  ( void );
+             bool  bIsValid( void ) { return( m_osErrMsg.IsEmpty( ) ); }
 
     virtual  bool  bParse ( void ) = 0;
     virtual  bool  bFormat( void ) = 0;
 
-    void  Print( const char * psPrefix="" );
+             bool  bSetString( wxString & ros );
+
+                   eSimrType    eGetSimEng ( void ) { return( m_eSimEng  ); }
+                   eCmdType     eGetCmdType( void ) { return( m_eCmdType ); }
+             const wxString & rosGetErrMsg ( void ) { return( m_osErrMsg ); }
+
+             void  SetErrMsg( const wxString & rosErrMsg )
+                                  { if( bIsValid( ) ) m_osErrMsg = rosErrMsg; }
+
+    virtual  CmdBase & operator = ( const CmdBase & roCmd  );
+
+    virtual  void  Print( const wxString & rosPrefix=wxT("") );
 };
 
 //*****************************************************************************
