@@ -1,12 +1,12 @@
 //*****************************************************************************
 //                               PnlAnaBase.hpp                               *
 //                              ----------------                              *
-//  Description : This class derives from the wxPanel class and provides a    *
-//                base class for all analysis panel classes.                  *
-//  Started     : 26/04/2004                                                  *
-//  Last Update : 09/10/2007                                                  *
-//  Copyright   : (C) 2004 by MSWaters                                        *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Description : This class derives from the wxPanel class and provides a     *
+//               base class for all analysis panel classes.                   *
+// Started     : 26/04/2004                                                   *
+// Last Update : 19/08/2009                                                   *
+// Copyright   : (C) 2004 by MSWaters                                         *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -32,9 +32,8 @@
 // Application Includes
 
 #include "TypeDefs.hpp"
+#include "netlist/Component.hpp"
 #include "utility/PnlValue.hpp"
-#include "netlist/NetList.hpp"
-#include "netlist/Simulation.hpp"
 
 // Local Constant Declarations
 
@@ -43,13 +42,27 @@
 
 class PnlAnaBase : public wxPanel
 {
-  private:
+  public :
+
+    // Enumerated type for the various groups of display controls
+    enum  eTypeCtlGrp
+    {
+      eCTLGRP_BASE,
+      eCTLGRP_SCALE,
+      eCTLGRP_INITC,
+      eCTLGRP_SIGSRC,
+      eCTLGRP_CPXPRT,
+      eCTLGRP_TEMP,
+
+      eCTLGRP_FST = eCTLGRP_BASE,
+      eCTLGRP_LST = eCTLGRP_TEMP
+    };
+
+  protected :
 
     // Error message
     wxString     m_osErrMsg;
 
-  protected:
-
     // Sweep settings
     wxStaticBox  m_oSbxSwpPars;
     PnlValue     m_oPnlStart;
@@ -57,7 +70,7 @@ class PnlAnaBase : public wxPanel
     PnlValue     m_oPnlStep;
 
     // Step scale specifier
-    wxRadioBox   m_oRbxStepScale;
+    wxRadioBox   m_oRbxScale;
 
     // Initial conditions
     wxRadioBox   m_oRbxInitC;
@@ -78,9 +91,9 @@ class PnlAnaBase : public wxPanel
     wxCheckBox   m_oCbxMagDb;
 
     // Input signal source, value and units
-    wxStaticBox  m_oSbxSigSrc;
-    wxChoice     m_oChoSigSrcCpnt;
-    PnlValue     m_oPnlSigSrcLvl;
+    wxStaticBox  m_oSbxSrc;
+    wxChoice     m_oChoSrcName;
+    PnlValue     m_oPnlSrcLvl;
 
     // .OPTIONS configuration dialog button
     wxButton     m_oBtnOPTIONS;
@@ -90,53 +103,43 @@ class PnlAnaBase : public wxPanel
     PnlValue     m_oPnlTemp;
 
     // The simulator engine and analysis types of the panel
-    eSimrType    m_eSimrType;
-    eAnaType     m_eAnaType;
+    eSimrType    m_eSimEng;
+    eCmdType     m_eAnaType;
 
     // Functions to create the display objects
     void  CreateBase  ( void );
-    void  CreateSigSrc( void );
+    void  CreateScale ( void );
+    void  CreateInitC ( void );
+    void  CreateSrc   ( void );
     void  CreateCpxPrt( void );
     void  CreateTemp  ( void );
+    bool  bIsCreated  ( enum eTypeCtlGrp eCtlGrp );
 
-    bool  bIsCreatedBase  ( void )
-              { return( m_oSbxSwpPars   .GetParent( )!=NULL ? TRUE : FALSE ); }
-    bool  bIsCreatedSigSrc( void )
-              { return( m_oChoSigSrcCpnt.GetParent( )!=NULL ? TRUE : FALSE ); }
-    bool  bIsCreatedCpxPrt( void )
-              { return( m_oSbxCpxPrt    .GetParent( )!=NULL ? TRUE : FALSE ); }
-    bool  bIsCreatedTemp  ( void )
-              { return( m_oPnlTemp      .GetParent( )!=NULL ? TRUE : FALSE ); }
-    bool  bIsCreatedScale ( void )
-              { return( m_oRbxStepScale .GetParent( )!=NULL ? TRUE : FALSE ); }
-    bool  bIsCreatedInitC ( void )
-              { return( m_oRbxInitC     .GetParent( )!=NULL ? TRUE : FALSE ); }
+    virtual  void  InitScale( void ) { }
 
-    void  LoadSigSrcCpnts( Simulation & roSim, wxString osPrefixes );
-    bool  bSetSigSrc( Simulation & roSim );
-    bool  bSetSigSrcUnits( void );
+    bool  bSetScale   ( eScaleType eScale );
+    bool  bSetInitC   ( eInitCType eInitC );
+    void  LoadSrcNames( ArrayComponent & roaCpnts, wxString osPrefixes );
+    bool  bSetSrcCpnt ( Component & roCpnt );
 
-  public:
+  public :
 
     PnlAnaBase( wxWindow * poWin );
    ~PnlAnaBase( );
 
     bool  bClear( void );
-    bool  bIsOk( void ) { return( m_osErrMsg.IsEmpty( ) ); }
+    bool  bIsOk ( void ) { return( m_osErrMsg.IsEmpty( ) ); }
 
-    bool  bSetSimrType( eSimrType eSimrType );
-    bool  bSetAnaType ( eAnaType  eAnaType );
+    bool  bSetSimrEng( eSimrType eSimrEng );
+    bool  bSetAnaType( eCmdType  eAnaType );
 
-    eSimrType  eGetSimrType( void ) { return( m_eSimrType ); }
-    eAnaType   eGetAnaType ( void ) { return( m_eAnaType ); }
+    eSimrType  eGetSimrEng( void ) { return( m_eSimEng ); }
+    eCmdType   eGetAnaType( void ) { return( m_eAnaType ); }
 
     const wxString & rosGetErrMsg( void ) { return( m_osErrMsg ); }
           void          SetErrMsg( const wxString & rosErrMsg )
                                      { if( bIsOk( ) ) m_osErrMsg = rosErrMsg; }
 
-    bool  bLoad( Simulation & roSim );
-    bool  bSave( Simulation & roSim );
-
     friend  class  FrmMain;
     friend  class  NbkGnuCap;
     friend  class  NbkNgSpice;
@@ -149,11 +152,11 @@ class PnlAnaBase : public wxPanel
       ID_PNL_STOP,
       ID_PNL_STEP,
 
-      ID_RBX_STEPSCALE,
+      ID_RBX_SCALE,
       ID_RBX_INITC,
 
-      ID_CHO_SIGSRCCPNT,
-      ID_PNL_SIGSRCLVL,
+      ID_CHO_SRCNAME,
+      ID_PNL_SRCLVL,
 
       ID_CBX_MAG,
       ID_CBX_PHASE,
