@@ -4,7 +4,7 @@
 //  Description : Provides a wrapper for the wxProcess class adding a bit of  *
 //                extra desirable functionality.                              *
 //  Started     : 29/01/2004                                                  *
-//  Last Update : 23/01/2008                                                  *
+//  Last Update : 14/07/2009                                                  *
 //  Copyright   : (C) 2004 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -67,23 +67,24 @@ class PrcBase : public wxProcess
     bool  bIsExec( void ) { return( m_iPid>0 ? TRUE : FALSE ); }
     bool  bIsOk  ( void ) { return( m_osErrMsg.IsEmpty( ) ); }
 
-    bool  bSetBinary ( const wxString & rosFileName  );
-    bool  bSetArgLst ( const wxString & rosArgLst );
-    bool  bSetLogFile( const wxString & rosFileName  );
+    bool  bSetBinary ( const wxString & rosFileName );
+    bool  bSetArgLst ( const wxString & rosArgLst   );
+    bool  bSetLogFile( const wxString & rosFileName );
+    void   SetErrMsg ( const wxString & rosErrMsg   )
+                                     { if( bIsOk( ) ) m_osErrMsg = rosErrMsg; }
 
     const wxFileName & rofnGetBinary ( void ) { return( m_ofnBinary ); }
     const wxString   &  rosGetArgLst ( void ) { return( m_osArgLst  ); }
     const wxFileName & rofnGetLogFile( void ) { return( m_ofnLog    ); }
     const wxString   &  rosGetErrMsg ( void ) { return( m_osErrMsg  ); }
 
-    bool  bExec( const wxString & rosArgLst=wxT("") );
-    bool  bKill( void );
+    virtual  bool  bExec( void );
+    virtual  bool  bKill( void );
 
     bool  bDelLogFile( void );
 
     void  OnTerminate( int iPid, int iStatus );
 
-    // The following functions are intended for debugging
     void  Print   ( TextCtrl & roTxtCtl );
     void  PrintCmd( TextCtrl & roTxtCtl );
     void  PrintRsp( TextCtrl & roTxtCtl );
