@@ -2,7 +2,7 @@
 //                                 NbkGnuCap.cpp                              *
 //                                ---------------                             *
 //  Started     : 05/09/2003                                                  *
-//  Last Update : 11/12/2007                                                  *
+//  Last Update : 13/10/2009                                                  *
 //  Copyright   : (C) 2003 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -37,10 +37,10 @@ END_EVENT_TABLE( )
 //   roSize   - The notebook size
 
 NbkGnuCap::NbkGnuCap( wxWindow * poParent, wxWindowID oWinID )
-                    : NbkSimrBase( poParent, oWinID ), m_oDlgOptions( poParent )
+                    : NbkSimrBase( poParent, oWinID ), m_oDlgCfgOPT( poParent )
 {
   // Set the simulator engine type specifier
-  bSetSimrType( eSIMR_GNUCAP );
+  m_eSimEng = eSIMR_GNUCAP;
 
   // Create the various display objects
   m_poPnlGnuCapOP = new PnlGnuCapOP( this );
@@ -50,10 +50,10 @@ NbkGnuCap::NbkGnuCap( wxWindow * poParent, wxWindowID oWinID )
   m_poPnlGnuCapFO = new PnlGnuCapFO( this );
 
   // Add the display objects to the note book
-  AddPage( m_poPnlGnuCapOP, wxT( " Quiescent  " ) );
+  AddPage( m_poPnlGnuCapOP, wxT( " Quiescent  "  ) );
   AddPage( m_poPnlGnuCapDC, wxT( "     DC      " ) );
   AddPage( m_poPnlGnuCapAC, wxT( "     AC      " ) );
-  AddPage( m_poPnlGnuCapTR, wxT( " Transient  " ) );
+  AddPage( m_poPnlGnuCapTR, wxT( " Transient  "  ) );
   AddPage( m_poPnlGnuCapFO, wxT( "   Fourier   " ) );
 
   // Specify the default page to be displayed
@@ -64,10 +64,10 @@ NbkGnuCap::NbkGnuCap( wxWindow * poParent, wxWindowID oWinID )
 // Default constructor.
 // (Used for two stage creation ie. must call Create( ) method.
 
-NbkGnuCap::NbkGnuCap( void ) : NbkSimrBase( ), m_oDlgOptions( this )
+NbkGnuCap::NbkGnuCap( void ) : NbkSimrBase( ), m_oDlgCfgOPT( this )
 {
   // Set the simulator engine type specifier
-  bSetSimrType( eSIMR_GNUCAP );
+  m_eSimEng = eSIMR_GNUCAP;
 }
 
 //*****************************************************************************
@@ -86,81 +86,122 @@ NbkGnuCap::~NbkGnuCap( )
 
 bool  NbkGnuCap::bClear( void )
 {
-  bool  bRtnValue=TRUE;
+  bool  bRtn=TRUE;
 
-  if( ! m_poPnlGnuCapOP->bClear( ) ) bRtnValue = FALSE;
-  if( ! m_poPnlGnuCapDC->bClear( ) ) bRtnValue = FALSE;
-  if( ! m_poPnlGnuCapAC->bClear( ) ) bRtnValue = FALSE;
-  if( ! m_poPnlGnuCapTR->bClear( ) ) bRtnValue = FALSE;
-  if( ! m_poPnlGnuCapFO->bClear( ) ) bRtnValue = FALSE;
+  // Clear the base class
+  if( ! NbkSimrBase    ::bClear( ) ) bRtn = FALSE;
 
-  if( ! m_oDlgOptions   .bClear( ) ) bRtnValue = FALSE;
+  if( ! m_poPnlGnuCapOP->bClear( ) ) bRtn = FALSE;
+  if( ! m_poPnlGnuCapDC->bClear( ) ) bRtn = FALSE;
+  if( ! m_poPnlGnuCapAC->bClear( ) ) bRtn = FALSE;
+  if( ! m_poPnlGnuCapTR->bClear( ) ) bRtn = FALSE;
+  if( ! m_poPnlGnuCapFO->bClear( ) ) bRtn = FALSE;
 
-  return( bRtnValue );
+  if( ! m_oDlgCfgOPT    .bClear( ) ) bRtn = FALSE;
+
+  return( bRtn );
 }
 
 //*****************************************************************************
-// Load information from a Simulation object.
+// Load information from a simulation object.
 //
 // Argument List:
-//   roSim - The simulation object
+//   roSimn - The simulation object
 //
 // Return Values:
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  NbkGnuCap::bLoad( Simulation & roSim )
+bool  NbkGnuCap::bLoad( const SimnBase & roSimn )
 {
-  bool  bRtnValue=TRUE;
+  bool  bRtn=TRUE;
 
-  if( ! m_poPnlGnuCapOP->bLoad( roSim ) )               bRtnValue = FALSE;
-  if( ! m_poPnlGnuCapDC->bLoad( roSim ) )               bRtnValue = FALSE;
-  if( ! m_poPnlGnuCapAC->bLoad( roSim ) )               bRtnValue = FALSE;
-  if( ! m_poPnlGnuCapTR->bLoad( roSim ) )               bRtnValue = FALSE;
-  if( ! m_poPnlGnuCapFO->bLoad( roSim ) )               bRtnValue = FALSE;
+  if( roSimn.eGetSimEng( ) != eSIMR_GNUCAP )             return( FALSE );
 
-  if( m_oDlgOptions.bSetCmd( roSim.rosGetOPTIONS( ) ) ) bRtnValue = FALSE;
+  SimnGnuCap & roSimnGcp = (SimnGnuCap &) roSimn;
 
-  if( ! bSetPage( roSim.eGetAnaType( ) ) )              bRtnValue = FALSE;
+  if( ! bSetPage( roSimnGcp.eGetAnaType( ) ) )           bRtn = FALSE;
 
-  return( bRtnValue );
+  if( ! m_poPnlGnuCapOP->bLoad( roSimnGcp ) )            bRtn = FALSE;
+  if( ! m_poPnlGnuCapDC->bLoad( roSimnGcp ) )            bRtn = FALSE;
+  if( ! m_poPnlGnuCapAC->bLoad( roSimnGcp ) )            bRtn = FALSE;
+  if( ! m_poPnlGnuCapTR->bLoad( roSimnGcp ) )            bRtn = FALSE;
+  if( ! m_poPnlGnuCapFO->bLoad( roSimnGcp ) )            bRtn = FALSE;
+
+  if( ! m_oDlgCfgOPT.bSetValues( roSimnGcp.m_oCmdOPT ) ) bRtn = FALSE;
+
+  return( bRtn );
 }
 
 //*****************************************************************************
 // Save information to a simulation object.
 //
 // Argument List:
-//   roSim - The simulation object
+//   roSimn - The simulation object
 //
 // Return Values:
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  NbkGnuCap::bSave( Simulation & roSim )
+bool  NbkGnuCap::bSave( SimnBase & roSimn )
 {
+  wxString  os1;
+
+  // Only proceed if this is an GNU-Cap simulation object
+  if( roSimn.eGetSimEng( ) != eSIMR_GNUCAP ) return( FALSE );
+
+  SimnGnuCap & roSimnGcp = (SimnGnuCap &) roSimn;
+
+  // Clear the error string
+  NbkSimrBase::m_osErrMsg.Empty( );
+
+  // Create the analysis command/s
   switch( GetSelection( ) )
   {
-    case 0: // OP analysis
-      if( ! m_poPnlGnuCapOP->bSave( roSim ) ) return( FALSE );
+    case 0 : // OP analysis
+      if( m_poPnlGnuCapOP->bSave( roSimnGcp ) )
+           os1.Empty( );
+      else SetErrMsg( m_poPnlGnuCapOP->rosGetErrMsg( ) );
       break;
-    case 1: // DC analysis
-      if( ! m_poPnlGnuCapDC->bSave( roSim ) ) return( FALSE );
-      break;
-    case 2: // AC analysis
-      if( ! m_poPnlGnuCapAC->bSave( roSim ) ) return( FALSE );
-      break;
-    case 3: // TR analysis
-      if( ! m_poPnlGnuCapTR->bSave( roSim ) ) return( FALSE );
-      break;
-    case 4: // FO analysis
-      if( ! m_poPnlGnuCapFO->bSave( roSim ) ) return( FALSE );
-      break;
-    default:                                  return( FALSE );
-  }
 
-  m_oDlgOptions.m_fTEMPAMB = roSim.fGetTempC( );
-  m_oDlgOptions.bFormat( );
-  roSim.bSetOPTIONS( (wxString) m_oDlgOptions );
+    case 1 : // DC analysis
+      if( m_poPnlGnuCapDC->bSave( roSimnGcp ) )
+           os1 = roSimnGcp.m_oCmdDC.m_osTempC;
+      else SetErrMsg( m_poPnlGnuCapDC->rosGetErrMsg( ) );
+      break;
+
+    case 2 : // AC analysis
+      if( m_poPnlGnuCapAC->bSave( roSimnGcp ) )
+           os1 = roSimnGcp.m_oCmdAC.m_osTempC;
+      else SetErrMsg( m_poPnlGnuCapAC->rosGetErrMsg( ) );
+      break;
+
+    case 3 : // TR analysis
+      if( m_poPnlGnuCapTR->bSave( roSimnGcp ) )
+           os1 = roSimnGcp.m_oCmdTR.m_osTempC;
+      else SetErrMsg( m_poPnlGnuCapTR->rosGetErrMsg( ) );
+      break;
+
+    case 4 : // FO analysis
+      if( m_poPnlGnuCapFO->bSave( roSimnGcp ) )
+           os1 = roSimnGcp.m_oCmdFO.m_osTempC;
+      else SetErrMsg( m_poPnlGnuCapFO->rosGetErrMsg( ) );
+      break;
+
+    default:                                 return( FALSE );
+  }
+  if( ! bIsOk( ) )                           return( FALSE );
+
+  // Create the OPTIONS command
+  m_oDlgCfgOPT.bGetValues( roSimnGcp.m_oCmdOPT );
+  if( ! os1.IsEmpty( ) ) roSimnGcp.m_oCmdOPT.m_osTEMPAMB = os1;
+  roSimnGcp.m_oCmdOPT.bFormat( );
+  if( ! roSimnGcp.m_oCmdOPT.bIsValid( ) )
+  {
+    os1 = wxT("OPTIONS command fault :\n\n  ");
+    SetErrMsg( os1 + roSimnGcp.m_oCmdOPT.rosGetErrMsg( ) );
+    return( FALSE );
+  }
 
   return( TRUE );
 }
@@ -169,24 +210,25 @@ bool  NbkGnuCap::bSave( Simulation & roSim )
 // Set the page to be displayed.
 //
 // Argument List:
-//   eType - The enumerated analysis type specifier
+//   eCmdType - The enumerated analysis type specifier
 //
 // Return Values:
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  NbkGnuCap::bSetPage( eAnaType eType )
+bool  NbkGnuCap::bSetPage( eCmdType eAnalysis )
 {
   int  iPage;
 
-  switch( eType )
+  switch( eAnalysis )
   {
-    case eANA_OP : iPage = 0; break;
-    case eANA_DC : iPage = 1; break;
-    case eANA_AC : iPage = 2; break;
-    case eANA_TR : iPage = 3; break;
-    case eANA_FO : iPage = 4; break;
-    default:                  return( FALSE );
+    case eCMD_NONE :
+    case eCMD_OP   : iPage = 0; break;
+    case eCMD_DC   : iPage = 1; break;
+    case eCMD_AC   : iPage = 2; break;
+    case eCMD_TR   : iPage = 3; break;
+    case eCMD_FO   : iPage = 4; break;
+    default        : return( FALSE );
   }
 
   SetSelection( iPage ); // Specify the page to be displayed
@@ -198,34 +240,34 @@ bool  NbkGnuCap::bSetPage( eAnaType eType )
 // Set the page to be displayed.
 //
 // Argument List:
-//   psType - The two letter analysis type specifier (case ignored)
+//   psAnalysis - The two letter analysis type specifier (case ignored)
 //
 // Return Values:
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  NbkGnuCap::bSetPage( const wxChar * psType )
+bool  NbkGnuCap::bSetPage( const wxChar * psAnalysis )
 {
-  eAnaType  eType=eANA_NONE;
-  wxString  osType;
+  eCmdType  ePage=eCMD_NONE;
+  wxString  osAnalysis;
 
-  osType = wxString( psType ).Upper( );
+  osAnalysis = wxString( psAnalysis ).Upper( );
 
-  if( osType.Length( ) == 2 )
+  if( osAnalysis.Length( ) == 2 )
   {
-         if( osType == wxT("OP") ) eType = eANA_OP;
-    else if( osType == wxT("DC") ) eType = eANA_DC;
-    else if( osType == wxT("AC") ) eType = eANA_AC;
-    else if( osType == wxT("TR") ) eType = eANA_TR;
-    else if( osType == wxT("FO") ) eType = eANA_FO;
-    else if( osType == wxT("DI") ) eType = eANA_DI;
-    else if( osType == wxT("NO") ) eType = eANA_NO;
-    else if( osType == wxT("PZ") ) eType = eANA_PZ;
-    else if( osType == wxT("SE") ) eType = eANA_SE;
-    else if( osType == wxT("TF") ) eType = eANA_TF;
+    if(      osAnalysis == wxT("OP") ) ePage = eCMD_OP;
+    else if( osAnalysis == wxT("DC") ) ePage = eCMD_DC;
+    else if( osAnalysis == wxT("AC") ) ePage = eCMD_AC;
+    else if( osAnalysis == wxT("TR") ) ePage = eCMD_TR;
+    else if( osAnalysis == wxT("FO") ) ePage = eCMD_FO;
+    else if( osAnalysis == wxT("DI") ) ePage = eCMD_DI;
+    else if( osAnalysis == wxT("NO") ) ePage = eCMD_NO;
+    else if( osAnalysis == wxT("PZ") ) ePage = eCMD_PZ;
+    else if( osAnalysis == wxT("SE") ) ePage = eCMD_SE;
+    else if( osAnalysis == wxT("TF") ) ePage = eCMD_TF;
   }
 
-  return( bSetPage( eType ) );
+  return( bSetPage( ePage ) );
 }
 
 //*****************************************************************************
@@ -241,12 +283,12 @@ const wxString & NbkGnuCap::rosGetPage( void )
 
   switch( eGetPage( ) )
   {
-    case eANA_OP : osPage = wxT("op"); break;
-    case eANA_DC : osPage = wxT("dc"); break;
-    case eANA_AC : osPage = wxT("ac"); break;
-    case eANA_TR : osPage = wxT("tr"); break;
-    case eANA_FO : osPage = wxT("fo"); break;
-    default :      osPage.Empty( );
+    case eCMD_OP : osPage = wxT("op"); break;
+    case eCMD_DC : osPage = wxT("dc"); break;
+    case eCMD_AC : osPage = wxT("ac"); break;
+    case eCMD_TR : osPage = wxT("tr"); break;
+    case eCMD_FO : osPage = wxT("fo"); break;
+    default      : osPage.Empty( );
   }
 
   return( osPage );
@@ -259,18 +301,18 @@ const wxString & NbkGnuCap::rosGetPage( void )
 //   Success - The enumerated analysis specifier
 //   Failure - Simulation::eANA_NONE
 
-eAnaType  NbkGnuCap::eGetPage( void )
+eCmdType  NbkGnuCap::eGetPage( void )
 {
-  eAnaType  ePage;
+  eCmdType  ePage;
 
   switch( GetSelection( ) )
   {
-    case 0 :  ePage = eANA_OP; break;
-    case 1 :  ePage = eANA_DC; break;
-    case 2 :  ePage = eANA_AC; break;
-    case 3 :  ePage = eANA_TR; break;
-    case 4 :  ePage = eANA_FO; break;
-    default : ePage = eANA_NONE;
+    case  0 : ePage = eCMD_OP; break;
+    case  1 : ePage = eCMD_DC; break;
+    case  2 : ePage = eCMD_AC; break;
+    case  3 : ePage = eCMD_TR; break;
+    case  4 : ePage = eCMD_FO; break;
+    default : ePage = eCMD_NONE;
   }
 
   return( ePage );
@@ -289,26 +331,26 @@ eAnaType  NbkGnuCap::eGetPage( void )
 void  NbkGnuCap::OnBtnOptions( wxCommandEvent & roEvtCmd )
 {
   PnlAnaBase * poPnlAna;
-  double       df1;
+  wxString     os1;
   int          i1;
 
   // Set the temperature in the OPTIONS dialog
   poPnlAna = (PnlAnaBase *) GetPage( GetSelection( ) );
-  if( poPnlAna->bIsCreatedTemp( ) )
+  if( poPnlAna->bIsCreated( PnlAnaBase::eCTLGRP_TEMP ) )
   {
-    df1 = poPnlAna->m_oPnlTemp.dfGetValue( );
-    m_oDlgOptions.bSetValue( DlgGnuCapOPT::ID_PNL_TEMPAMB, (float) df1 );
+    os1 = poPnlAna->m_oPnlTemp.rosGetValue( );
+    m_oDlgCfgOPT.bSetValue( DlgGcpCfgOPT::ID_PNL_TEMPAMB, os1 );
   }
 
   // Display the OPTIONS dialog
-  m_oDlgOptions.CenterOnParent( );
-  i1 = m_oDlgOptions.ShowModal( );
+  m_oDlgCfgOPT.CenterOnParent( );
+  i1 = m_oDlgCfgOPT.ShowModal( );
 
   // Set the temperature in the analysis panel
-  if( i1==wxID_OK && poPnlAna->bIsCreatedTemp( ) )
+  if( poPnlAna->bIsCreated( PnlAnaBase::eCTLGRP_TEMP ) && i1==wxID_OK )
   {
-    df1 = m_oDlgOptions.dfGetValue( DlgGnuCapOPT::ID_PNL_TEMPAMB );
-    poPnlAna->m_oPnlTemp.bSetValue( df1 );
+    os1 = m_oDlgCfgOPT.rosGetValue( DlgGcpCfgOPT::ID_PNL_TEMPAMB );
+    poPnlAna->m_oPnlTemp.bSetValue( os1 );
   }
 }
 
