@@ -1,10 +1,10 @@
 //*****************************************************************************
 //                              CmdGnuCapDC.cpp                               *
 //                             -----------------                              *
-//  Started     : 29/01/2008                                                  *
-//  Last Update : 22/02/2008                                                  *
-//  Copyright   : (C) 2008 by M.S.Waters                                      *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Started     : 29/01/2008                                                   *
+// Last Update : 14/10/2009                                                   *
+// Copyright   : (C) 2008 by M.S.Waters                                       *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -33,6 +33,84 @@ CmdGnuCapDC::~CmdGnuCapDC( )
 {
 }
 
+//*****************************************************************************
+// Check that the object attributes are valid.
+//
+// Return Values :
+//   TRUE  - Success
+//   FALSE - Failure
+
+bool  CmdGnuCapDC::bValidate( void )
+{
+  double  df1, df2, df3;
+
+  CmdBase::bValidate( );
+
+  // Check the sweep start and stop values
+  if( ! ConvertType::bStrToDFlt( m_osStart, &df1 ) )
+    SetErrMsg( wxT("Invalid sweep start value.") );
+  if( ! ConvertType::bStrToDFlt( m_osStop,  &df2 ) )
+    SetErrMsg( wxT("Invalid sweep stop value.") );
+  if( df2 < df1 )
+    SetErrMsg( wxT("Start value greater than stop value.") );
+
+  // Check the sweep step value and sweep scale
+  if( ! ConvertType::bStrToDFlt( m_osStep, &df3 ) )
+    SetErrMsg( wxT("Invalid sweep step value.") );
+  if( df3 <= 0.0 )
+    SetErrMsg( wxT("Step value less than or equal to zero.") );
+  switch( m_eScale )
+  {
+    case eSCALE_LIN :
+      if( df1!=df2 && df3>fabs( df2 - df1 ) )
+        SetErrMsg( wxT("Step value is greater than sweep range.") );
+      break;
+    case eSCALE_LOG :
+      if( df1!=df2 && df3==1.0 )
+        SetErrMsg( wxT("Invalid step multiplier, must be non-unity.") );
+      break;
+    case eSCALE_DEC : break;
+    default         : SetErrMsg( wxT("Invalid step scale value.") );
+  }
+
+  // Check the component to be used as the sweep source
+  if( m_osSource.IsEmpty( ) )
+    SetErrMsg( wxT("No source component has been selected.") );
+
+  // Set the analysis temperature
+  if( ! ConvertType::bStrToDFlt( m_osTempC, &df3 ) )
+    SetErrMsg( wxT("Invalid analysis temperature value.") );
+
+  return( bIsValid( ) );
+}
+
+//*****************************************************************************
+// Clear the object attributes.
+//
+// Return Values :
+//   TRUE  - Success
+//   FALSE - Failure
+
+bool  CmdGnuCapDC::bClear( void )
+{
+  CmdBase::bClear( );
+
+  m_eSimEng  = eSIMR_GNUCAP;
+  m_eCmdType = eCMD_DC;
+
+  m_osStart  = wxT("0.0");
+  m_osStop   = wxT("100.0");
+  m_osStep   = wxT("10.0");
+
+  m_osSource = wxT("None");
+
+  m_eScale   = eSCALE_LIN;
+
+  m_osTempC  = wxT("0.0");
+
+  return( TRUE );
+}
+
 //*****************************************************************************
 // Parse the command string.
 //
@@ -49,39 +127,35 @@ bool  CmdGnuCapDC::bParse( void )
   wxStringTokenizer  ostk1;
   wxString           os1;
   double             df1;
-  long               li1;
   int                i1;
 
   // Clear the object attributes
-  os1 = *this;
+  os1 = (wxString &) *this;
   bClear( );
-  *this = os1;
+  assign( os1 );
 
   // Tokenize the command string
   ostk1.SetString( *this );
   i1 = ostk1.CountTokens( );
-  if( i1!=6 && i1!=9 )                                 return( FALSE );
+  if( i1!=6 && i1!=9 )                                 return( bValidate( ) );
 
   // Check command type
   os1 = ostk1.GetNextToken( ).Left( 3 ).Upper( );
-  if( os1 != wxT(".DC") )                              return( FALSE );
-  m_osName = wxT("DC");
-
-  m_bIsOk = TRUE;
+  if( os1 != wxT(".DC") )                              return( bValidate( ) );
 
   // Extract the sweep source label
   m_osSource = ostk1.GetNextToken( );
-  if( m_osSource.IsEmpty( ) ) m_bIsOk = FALSE;
+  if( m_osSource.IsEmpty( ) )                          return( bValidate( ) );
 
   // Extract the start value
   os1 = ostk1.GetNextToken( );
-  if( ConvertType::bStrToFlt( os1, &df1 ) ) m_fStart = (float) df1;
-  else                                                 m_bIsOk = FALSE;
+  if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osStart = os1;
+  else                                                 return( bValidate( ) );
 
   // Extract the stop voltage
   os1 = ostk1.GetNextToken( );
-  if( ConvertType::bStrToFlt( os1, &df1 ) ) m_fStop = (float) df1;
-  else                                                 m_bIsOk = FALSE;
+  if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osStop = os1;
+  else                                                 return( bValidate( ) );
 
   // Extract the sweep type: linear, log or steps per decade
   os1 = ostk1.GetNextToken( );
@@ -89,34 +163,26 @@ bool  CmdGnuCapDC::bParse( void )
   if(      os1 == wxT("BY") ) m_eScale = eSCALE_LIN;
   else if( os1 == wxT("TI") ) m_eScale = eSCALE_LOG;
   else if( os1 == wxT("DE") ) m_eScale = eSCALE_DEC;
-  else                                                 m_bIsOk = FALSE;
+  else                                                 return( bValidate( ) );
 
   // Extract the step size/count
   os1 = ostk1.GetNextToken( );
-  if( m_eScale <= eSCALE_LOG )
-  {
-    if( ConvertType::bStrToFlt( os1, &df1 ) ) m_fStep = (float) df1;
-    else                                             m_bIsOk = FALSE;
-  }
-  else
-  {
-    if( ConvertType::bStrToInt( os1, &li1 ) ) m_fStep = (float) li1;
-    else                                             m_bIsOk = FALSE;
-  }
+  if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osStep = os1;
+  else                                                 return( bValidate( ) );
 
   // Extract the analysis temperature
   os1 = ostk1.GetNextToken( );
   if( os1.Upper( ) == wxT("TE") )
   {
     os1 = ostk1.GetNextToken( );
-    if( ConvertType::bStrToFlt( os1, &df1 ) ) m_fTempC = (float) df1;
-    else                                               m_bIsOk = FALSE;
+    if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osTempC = os1;
+    else                                               return( bValidate( ) );
   }
 
   // Check that the last field is "BASIC"
-  if( ostk1.GetNextToken( ).Upper( ) != wxT("BASIC") ) m_bIsOk = FALSE;
+  if( ostk1.GetNextToken( ).Upper( ) != wxT("BASIC") ) return( bValidate( ) );
 
-  return( m_bIsOk );
+  return( bValidate( ) );
 }
 
 //*****************************************************************************
@@ -130,89 +196,79 @@ bool  CmdGnuCapDC::bFormat( void )
 {
   wxString  osCmd, os1;
 
-  m_bIsOk = FALSE;
-
   // Set the command name
   osCmd = wxT(".DC");
-  if( m_osName.IsEmpty( ) ) m_osName = wxT("DC");
 
   // Set signal source
   osCmd << wxT(' ') << m_osSource;
 
   // Set sweep parameters
-  if( ! ConvertType::bFltToStrEng( (double) m_fStart, os1 ) )   return( FALSE );
-  osCmd << wxT(' ') << os1;
-  if( ! ConvertType::bFltToStrEng( (double) m_fStop,  os1 ) )   return( FALSE );
-  osCmd << wxT(' ') << os1;
+  osCmd << wxT(' ') << m_osStart;
+  osCmd << wxT(' ') << m_osStop;
   switch( m_eScale )
   {
     case eSCALE_LIN : osCmd << wxT(" BY"); break;
     case eSCALE_LOG : osCmd << wxT(" TI"); break;
     case eSCALE_DEC : osCmd << wxT(" DE"); break;
-    default         :                                           return( FALSE );
+    default         : break;
   }
-  if( m_eScale < eSCALE_DEC )
-  {
-    if( ! ConvertType::bFltToStrEng( (double) m_fStep,  os1 ) ) return( FALSE );
-    osCmd << wxT(' ') << os1;
-  }
-  else osCmd << wxT(' ') << (int) lroundf( m_fStep );
+  osCmd << wxT(' ') << m_osStep;
 
   // Set analysis temperature
-  if( ! ConvertType::bFltToStrEng( (double) m_fTempC, os1 ) )   return( FALSE );
-  osCmd << wxT(" TE ") << os1;
+  osCmd << wxT(" TE ") << m_osTempC;
 
   // Append format modifier
   osCmd << wxT(" BASIC");
 
-  *this = osCmd;
+  assign( osCmd );
 
-  m_bIsOk = TRUE;
-
-  return( m_bIsOk );
+  return( bValidate( ) );
 }
 
 //*****************************************************************************
-// Clear the object attributes.
+// Copy the contents of a CmdNgSpiceDC object.
+//
+// Argument List :
+//   roCmdDC - A reference to a CmdNgSpiceDC object
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   A reference to this object
 
-bool  CmdGnuCapDC::bClear( void )
+CmdGnuCapDC & CmdGnuCapDC::operator = ( const CmdNgSpiceDC & roCmdDC )
 {
-  CmdBase::bClear( );
+  (CmdBase &) *this = (CmdBase &) roCmdDC;
 
-  m_fStart = -FLT_MAX;
-  m_fStop  = -FLT_MAX;
-  m_fStep  = -FLT_MAX;
+  m_osStart  = roCmdDC.m_osStart;
+  m_osStop   = roCmdDC.m_osStop;
+  m_osStep   = roCmdDC.m_osStep;
+  m_osSource = roCmdDC.m_osSource;
 
-  m_osSource.Empty( );
+  bFormat( );
 
-  m_eScale = eSCALE_NONE;
-
-  m_fTempC = -FLT_MAX;
-
-  return( TRUE );
+  return( *this );
 }
 
 //*****************************************************************************
 // Print the object attributes.
 //
 // Argument List :
-//   psPrefix - A prefix to every line displayed (usually just spaces)
+//   rosPrefix - A prefix to every line displayed (usually just spaces)
 
-void  CmdGnuCapDC::Print( const char * psPrefix )
+void  CmdGnuCapDC::Print( const wxString & rosPrefix )
 {
-  CmdBase::Print( psPrefix );
+  CmdBase::Print( rosPrefix + wxT("CmdBase::") );
 
-  cout << psPrefix << "m_fStart   : " << m_fStart << '\n';
-  cout << psPrefix << "m_fStop    : " << m_fStop << '\n';
-  cout << psPrefix << "m_fStep    : " << m_fStep << '\n';
+  cout << rosPrefix .mb_str( ) << "m_osStart  : "
+       << m_osStart .mb_str( ) << '\n';
+  cout << rosPrefix .mb_str( ) << "m_osStop   : "
+       << m_osStop  .mb_str( ) << '\n';
+  cout << rosPrefix .mb_str( ) << "m_osStep   : "
+       << m_osStep  .mb_str( ) << '\n';
 
-  cout << psPrefix << "m_osSource : " << m_osSource.mb_str( ) << '\n';
+  cout << rosPrefix .mb_str( ) << "m_osSource : "
+       << m_osSource.mb_str( ) << '\n';
 
-  cout << psPrefix << "m_eScale   : ";
+  cout << rosPrefix .mb_str( ) << "m_eScale   : ";
   switch( m_eScale )
   {
     case eSCALE_LIN  : cout << "eSCALE_LIN\n";  break;
@@ -220,9 +276,11 @@ void  CmdGnuCapDC::Print( const char * psPrefix )
     case eSCALE_DEC  : cout << "eSCALE_DEC\n";  break;
     case eSCALE_OCT  : cout << "eSCALE_OCT\n";  break;
     case eSCALE_NONE : cout << "eSCALE_NONE\n"; break;
+    default :          cout << "Invalid\n";     break;
   }
 
-  cout << psPrefix << "m_fTempC   : " << m_fTempC << '\n';
+  cout << rosPrefix .mb_str( ) << "m_osTempC  : "
+       << m_osTempC .mb_str( ) << '\n';
 }
 
 //*****************************************************************************
@@ -263,7 +321,7 @@ int  main( int argc, char * argv[ ] )
 
   // Display the utility banner
   cout << "\n  Class CmdGnuCapDC Test Utility"
-       << "\n    Version 1.01 (22/02/2008)\n";
+       << "\n    Version 1.03 (04/06/2009)\n";
 
   // Create a GNU-CAP DC command object
   CmdGnuCapDC  tCmd_DC;
@@ -273,12 +331,12 @@ int  main( int argc, char * argv[ ] )
 
   // Set things up for a formatter test
   tCmd_DC.bClear( );
-  tCmd_DC.m_fStart   = 0.0;
-  tCmd_DC.m_fStop    = 100.0E-3;
-  tCmd_DC.m_fStep    = 10.0E-3;
+  tCmd_DC.m_osStart  = wxT("0.00");
+  tCmd_DC.m_osStop   = wxT("100.00m");
+  tCmd_DC.m_osStep   = wxT("10.00m");
   tCmd_DC.m_osSource = wxT("Vin");
   tCmd_DC.m_eScale   = eSCALE_LOG;
-  tCmd_DC.m_fTempC   = 27.0;
+  tCmd_DC.m_osTempC  = wxT("27.00");
   cout << "\nRun Formatter    : " << ( tCmd_DC.bFormat( ) ? "OK" : "FAULT" );
   cout << "\nTest Cmd Format  : " << ( tCmd_DC == osCmd   ? "OK" : "FAULT" );
   cout << "\nExample Command  : " << osCmd  .mb_str( );
@@ -286,7 +344,7 @@ int  main( int argc, char * argv[ ] )
 
   // Set things up for a parser test
   tCmd_DC.bClear( );
-  tCmd_DC = osCmd;
+  tCmd_DC.bSetString( osCmd );
   cout << "\nRun Parser       : " << ( tCmd_DC.bParse( ) ? "OK" : "FAULT" );
   tCmd_DC.bFormat( );
   cout << "\nTest Cmd Format  : " << ( tCmd_DC == osCmd  ? "OK" : "FAULT" );
