@@ -1,12 +1,12 @@
 //*****************************************************************************
 //                              CmdGnuCapDC.hpp                               *
 //                             -----------------                              *
-//  Description : This class contains values associated with the GNU-Cap DC   *
-//                command. It inherits from the class CmdBase.                *
-//  Started     : 29/01/2008                                                  *
-//  Last Update : 21/02/2008                                                  *
-//  Copyright   : (C) 2008 by M.S.Waters                                      *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Description : This class contains values associated with the GNU-Cap       *
+//               DC command. It inherits from the class CmdBase.              *
+// Started     : 29/01/2008                                                   *
+// Last Update : 13/05/2009                                                   *
+// Copyright   : (C) 2008 by M.S.Waters                                       *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -35,37 +35,42 @@ using  namespace  std;
 
 // Application Includes
 
-#include "TypeDefs.hpp"
 #include "base/CmdBase.hpp"
+#include "ngspice/commands/CmdNgSpiceDC.hpp"
 #include "utility/ConvertType.hpp"
 
+struct CmdNgSpiceDC;
+
 // Local Macro and Constant Declarations
 
 //*****************************************************************************
 
 struct CmdGnuCapDC : public CmdBase
 {
+  private :
+
+    virtual  bool  bValidate( void );
+
   public :
 
-    float       m_fStart;    // Sweep start value
-    float       m_fStop;     // Sweep stop  value
-    float       m_fStep;     // Sweep step  value
-    wxString    m_osSource;  // Sweep source
+    wxString    m_osStart;   // Sweep start value
+    wxString    m_osStop;    // Sweep stop  value
+    wxString    m_osStep;    // Sweep step  value
     eScaleType  m_eScale;    // Step scale
-    float       m_fTempC;    // Analysis temperature in Celcius
+    wxString    m_osSource;  // Sweep source
+    wxString    m_osTempC;   // Analysis temperature in Celcius
 
               CmdGnuCapDC( void );
     virtual  ~CmdGnuCapDC( );
 
-    bool  bClear( void );
+    virtual  bool  bClear( void );
 
     virtual  bool  bParse ( void );
     virtual  bool  bFormat( void );
 
-    wxString & operator = ( const wxString & ros )
-                { *((wxString *) this) = ros; return( *((wxString *) this) ); }
+    CmdGnuCapDC & operator = ( const CmdNgSpiceDC & roCmdDC );
 
-    void  Print( const char * psPrefix="" );
+    void  Print( const wxString & rosPrefix=wxT("  ") );
 };
 
 //*****************************************************************************
