@@ -3,7 +3,7 @@
 //                               --------------                               *
 //  Description : This dialogue is used to enter applications preferences.    *
 //  Started     : 17/10/2006                                                  *
-//  Last Update : 28/02/2008                                                  *
+//  Last Update : 18/09/2009                                                  *
 //  Copyright   : (C) 2006 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -32,8 +32,10 @@
 
 // Application Includes
 
+#include "CmdLinePcr.hpp"
 #include "utility/PnlValue.hpp"
 #include "utility/TextCtrl.hpp"
+#include "utility/ConvertType.hpp"
 
 // Local Constant Declarations
 
@@ -42,16 +44,18 @@
 
 class DlgPrefs : public wxDialog
 {
-  private:
+  private :
 
     // Pointer to global configuration object
-    wxConfig    * m_poConfig;
+    wxConfig    * m_poCfg;
 
     // Display controls
-    wxStaticText  m_oLblWaveViewer;
-    wxChoice      m_oChoWaveViewer;
+    wxStaticText  m_oLblViewer;
+    wxChoice      m_oChoViewer;
     wxStaticText  m_oLblTmpFileMgt;
     wxChoice      m_oChoTmpFileMgt;
+    wxStaticText  m_oLblPrecision;
+    wxChoice      m_oChoPrecision;
     PnlValue      m_oPnlMaxLines;
     wxCheckBox    m_oCbxToolTips;
 
@@ -65,20 +69,26 @@ class DlgPrefs : public wxDialog
     void  ToolTips  ( void );
     void  DoLayout  ( void );
 
-    void  SetValues( void );
-    void  GetValues( void );
+    void  Load( void );
+    void  Save( void );
 
-  public:
+  public :
 
     DlgPrefs( wxWindow * poWin );
    ~DlgPrefs( );
 
     bool  bClear( void );
 
-    const  wxString  rosGetWaveViewer( void )
-                          { return( m_oChoWaveViewer.GetStringSelection( ) ); }
-    int  iGetMaxLines  ( void ) { return( (int) m_oPnlMaxLines.liGetValue( ) ); }
-    int  iGetTmpFileMgt( void ) { return( m_oChoTmpFileMgt.GetSelection( ) ); }
+    const  wxString  rosGetViewer    ( void )
+                              { return( m_oChoViewer.GetStringSelection( ) ); }
+           int         iGetMaxLines  ( void )
+                              { return( (int) m_oPnlMaxLines.liGetValue( ) ); }
+           int         iGetTmpFileMgt( void )
+                              { return( m_oChoTmpFileMgt.GetSelection( )   ); }
+           int         iGetPrecision ( void )
+                              { return( m_oChoPrecision.GetSelection( )    ); }
+           bool        bGetToolTips  ( void )
+                              { return( m_oCbxToolTips.IsChecked( )        ); }
 
     // Event handlers
     void  OnBtnOk    ( wxCommandEvent & roEvtCmd );
@@ -90,19 +100,21 @@ class DlgPrefs : public wxDialog
     // unique identifier such as a const or an enum.
     enum eDlgItemID
     {
-      ID_PNL_MAXLINES = 0,
+      ID_CHO_SIMENG = 0,
+      ID_CHO_VIEWER,
+      ID_CHO_TMPFILEMGT,
+      ID_CHO_PRECISION,
+
+      ID_PNL_MAXLINES,
 
       ID_CBX_TOOLTIPS,
 
-      ID_CHO_WAVEVIEWER,
-      ID_CHO_TMPFILEMGT,
-
       ID_BTN_OK,
       ID_BTN_CANCEL,
 
       ID_UNUSED,      // Assigned to controls for which events are not used
 
-      ID_FST = ID_PNL_MAXLINES,
+      ID_FST = ID_CHO_SIMENG,
       ID_LST = ID_BTN_CANCEL
     };
 
