@@ -1,12 +1,12 @@
 //*****************************************************************************
 //                                FileTasks.hpp                               *
 //                               ---------------                              *
-//  Description : This is a helper class for FrmMain, it handles most of the  *
-//                required file operations.                                   *
-//  Started     : 28/05/2005                                                  *
-//  Last Update : 18/02/2008                                                  *
-//  Copyright   : (C) 2005 by M.S.Waters                                      *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Description : This is a helper class for FrmMain, it handles most of the   *
+//               file operations.                                             *
+// Started     : 28/05/2005                                                   *
+// Last Update : 19/08/2009                                                   *
+// Copyright   : (C) 2005 by M.S.Waters                                       *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -35,7 +35,8 @@
 class FrmMain;
 
 #include "Version.hpp"
-#include "netlist/Simulation.hpp"
+#include "TypeDefs.hpp"
+#include "base/SimnBase.hpp"
 #include "process/PrcGSchem.hpp"
 #include "process/PrcGNetList.hpp"
 
@@ -43,64 +44,48 @@ class FrmMain;
 
 class FileTasks
 {
-  public :
-
-    enum eTmpFMgtType
-    {
-      eTFM_DELETE=0,
-      eTFM_PROMPT,
-      eTFM_KEEP,
-      eTFM_NONE,
-
-      eTFM_FST = eTFM_DELETE,
-      eTFM_LST = eTFM_KEEP
-    };
-
   private :
 
-    FrmMain     * m_poFrmMain;     // Pointer to application main frame
-    wxConfig    * m_poConfig;      // Pointer to global configuration object
-    eTmpFMgtType  m_eTmpFileMgt;   // Temporary file management strategy
-    PrcGNetList   m_oPrcGNetList;  // gNetList file conversion utility
+    FrmMain    * m_poFrmMain;     // Pointer to application main frame
+    wxConfig   * m_poCfg;         // Pointer to global configuration object
+    PrcGNetList  m_oPrcGNetList;  // gNetList file conversion utility
 
     // Object initialization functions
-    void  InitTmpFileMgt( void );
     void  InitGuileProc ( void );
-    void  InitSchemFiles( void );
     void  InitNetLstFile( void );
+    void  InitSchemFiles( void );
 
-    void  DlgNetLstErr( void );
-    void  DlgSchemsErr( void );
+    void  DlgErrNetLst  ( void );
+    void  DlgErrSchems  ( void );
 
-    bool  bDlgOpen    ( void );
-    bool  bDlgImport  ( void );
-    bool  bExecImport ( void );
-    bool  bDelTmpFiles( void );
+    bool  bDlgOpen      ( void );
+    bool  bDlgImport    ( void );
+    bool  bExecImport   ( void );
+    bool  bDelTmpFiles  ( void );
 
   public :
 
     FileTasks( FrmMain * poFrmMain );
    ~FileTasks( );
 
-    bool  bClear( void );     // Clear the object attributes
-    void  Initialize( void ); // This function calls the initialization funcs
+    void  Initialize( void ); // This function calls all the initialization fns
+
     bool  bIsOkGNetList( void );
 
     bool  bSetTitle     ( void );
-    bool  bSetGuileProc ( const wxString & rosProcName );
-    bool  bSetSchemFiles( const wxArrayString & roasFileNames );
-    bool  bSetNetLstFile( const wxString & rosFileName );
-    bool  bSetTmpFileMgt( eTmpFMgtType eTFM );
-    bool  bSetLogFile   ( const wxString & rosFileName )
-                       { return( m_oPrcGNetList.bSetLogFile( rosFileName ) ); }
+    bool  bSetGuileProc ( const wxString & rosPName  );
+    bool  bSetNetLstFile( const wxString & rosFName  );
+    bool  bSetSchemFiles( const wxString & rosFNames );
+    bool  bSetLogFile   ( const wxString & rosFName  )
+                          { return( m_oPrcGNetList.bSetLogFile( rosFName ) ); }
 
     const wxString      &  rosGetGuileProc ( void );
-    const wxArrayString & roasGetSchemFiles( void );
     const wxString      &  rosGetNetLstFile( void );
+    const wxArrayString & rosaGetSchemFiles( void );
 
-    bool  bOpen  ( Simulation & roSim );
-    bool  bImport( Simulation & roSim );
-    bool  bReload( Simulation & roSim );
+    bool  bOpen  ( void );
+    bool  bImport( void );
+    bool  bReload( void );
     bool  bClose ( void );
     bool  bExit  ( void );
 };
