@@ -4,7 +4,7 @@
 //  Description : The main frame used to contain the applications display     *
 //                objects.                                                    *
 //  Started     : 18/08/2003                                                  *
-//  Last Update : 22/02/2008                                                  *
+//  Last Update : 18/09/2009                                                  *
 //  Copyright   : (C) 2003 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -39,23 +39,25 @@ using  namespace  std;
 
 // Application Includes
 
-class FrmMain;  // Only line required to compile FrmMain.o
-
 #include "TypeDefs.hpp"
+
 #include "main/FileTasks.hpp"
 #include "main/HelpTasks.hpp"
-#include "main/NbkTxtCtls.hpp"
-#include "main/DlgPrefs.hpp"
-#include "gnucap/NbkGnuCap.hpp"
-#include "ngspice/NbkNgSpice.hpp"
 #include "netlist/NetList.hpp"
-#include "netlist/Simulation.hpp"
+#include "netlist/SimnGnuCap.hpp"
+#include "netlist/SimnNgSpice.hpp"
+
 #include "process/PrcGnuCap.hpp"
 #include "process/PrcNgSpice.hpp"
 #include "process/PrcGSchem.hpp"
 #include "process/PrcGaw.hpp"
 #include "process/PrcGWave.hpp"
 
+#include "main/NbkTxtCtls.hpp"
+#include "main/DlgPrefs.hpp"
+#include "gnucap/NbkGnuCap.hpp"
+#include "ngspice/NbkNgSpice.hpp"
+
 // Local Constant Declarations
 
 
@@ -65,42 +67,49 @@ class FrmMain : public wxFrame
 {
   private :
 
-    bool          m_bIsOpen;     // Flag indicating when the frame has closed
-    wxConfig    * m_poConfig;    // Pointer to the configuration object
-    const wxApp * m_poApp;       // Pointer to the frames parent application
-    FileTasks     m_oFileTsks;   // Class to handler file operations
-    HelpTasks     m_oHelpTsks;   // Class to handler help operations
-    Simulation    m_oSim;        // Simulation object
-    PrcSimrBase * m_poPrcSimr;   // Pointer to the simulator process
-    PrcGSchem     m_oPrcGSchem;  // Object to schematic file
-    PrcGaw        m_oPrcGaw;     // Object to view simulation results
-    PrcGWave      m_oPrcGWave;   // Object to view simulation results
-    DlgPrefs      m_oDlgPrefs;   // The application preferences dialog
-    wxString      m_osErrMsg;    // An object wide error message string
+    // Object attributes
+    bool          m_bIsOpen;      // Flag indicating when the frame has closed
+
+    wxConfig    * m_poCfg;        // Pointer to the configuration object
+    const wxApp * m_poApp;        // Pointer to the frames parent application
+
+    FileTasks     m_oFileTsks;    // Class to handler file operations
+    HelpTasks     m_oHelpTsks;    // Class to handler help operations
+
+    NetList       m_oNetLst;      // The netlist object
+    SimnNgSpice   m_oSimnNgs;     // NG-Spice simulation object
+    SimnGnuCap    m_oSimnGcp;     // GNU-Cap  simulation object
+    SimnBase    * m_poSimultn;    // A pointer to the simulation object
+
+    PrcSimrBase * m_poPrcSimEng;  // Pointer to the simulator engine process
+    PrcGSchem     m_oPrcGSchem;   // Process object to schematic capture
+    PrcGaw        m_oPrcGaw;      // Process object to view simulation results
+    PrcGWave      m_oPrcGWave;    // Process object to view simulation results
 
     // Display control objects
-    NbkSimrBase * m_poNbkSimr;
-    wxStaticText  m_oLblNodes;
-    wxListBox     m_oLbxNodes;
-    wxStaticText  m_oLblCpnts;
-    wxListBox     m_oLbxCpnts;
-    NbkTxtCtls    m_oNbkTxtCtls;
+    NbkSimrBase * m_poNbkSimEng;  // Pointer to the simulation engine notebook
+    wxStaticText  m_oLblNodes;    // Label above the test nodes list
+    wxListBox     m_oLbxNodes;    // List of possible test nodes
+    wxStaticText  m_oLblCpnts;    // Label above the test components list
+    wxListBox     m_oLbxCpnts;    // List of possible test components
+    NbkTxtCtls    m_oNbkTxtCtls;  // Notebook containing the text controls
 
     // Object initialization functions
+    void  Initialize  ( void );
     void  InitMenuBar ( void );
     void  InitToolBar ( void );
     void  InitLstBoxs ( void );
-    void  InitSimrEng ( void );
     void  InitNbkTCtls( void );
     void  InitStatBar ( void );
     void  InitToolTips( void );
+    void  InitSimEng  ( void );
     void  InitLogFiles( void );
     void  InitPosnSize( void );
     void  DoLayout( void );
 
-    bool  bSimLoad  ( bool bReload=FALSE );  // Load   from Simulation object
-    bool  bSimReload( void );                // Reload from Simulation object
-    bool  bSimSave  ( void );                // Save   to   Simulation object
+    bool  bSimLoad  ( void );
+    bool  bSimReload( void );
+    bool  bSimSave  ( void );
 
     void  DlgErrMsg( const wxString & rosTitle, const wxString & rosMsg );
 
@@ -115,28 +124,26 @@ class FrmMain : public wxFrame
 
     bool  bIsOpen( void ) { return( m_bIsOpen ); }
 
-    bool  bClear( void );     // Clear the object attributes
-    void  Initialize( void ); // This function calls the initialization funcs
+    bool  bClear( void );  // Clear the object attributes
 
     // Event handlers
-    void  OnOpen     ( wxCommandEvent  & roEvtCmd );
-    void  OnImport   ( wxCommandEvent  & roEvtCmd );
-    void  OnReload   ( wxCommandEvent  & roEvtCmd );
-    void  OnClose    ( wxCommandEvent  & roEvtCmd );
-    void  OnAppExit  ( wxCommandEvent  & roEvtCmd );
-    void  OnSimCreate( wxCommandEvent  & roEvtCmd );
-    void  OnSimRun   ( wxCommandEvent  & roEvtCmd );
-    void  OnSimStop  ( wxCommandEvent  & roEvtCmd );
-    void  OnEdit     ( wxCommandEvent  & roEvtCmd );
-    void  OnPlot     ( wxCommandEvent  & roEvtCmd );
-    void  OnSelSimr  ( wxCommandEvent  & roEvtCmd );
-    void  OnPrefs    ( wxCommandEvent  & roEvtCmd );
-    void  OnManual   ( wxCommandEvent  & roEvtCmd );
-    void  OnAbout    ( wxCommandEvent  & roEvtCmd );
-    void  OnTbrEnter ( wxCommandEvent  & roEvtCmd );
-    void  OnSysExit  ( wxCloseEvent    & roEvtClose );
+    void  OnOpen     ( wxCommandEvent & roEvtCmd   );
+    void  OnImport   ( wxCommandEvent & roEvtCmd   );
+    void  OnReload   ( wxCommandEvent & roEvtCmd   );
+    void  OnClose    ( wxCommandEvent & roEvtCmd   );
+    void  OnAppExit  ( wxCommandEvent & roEvtCmd   );
+    void  OnSimCreate( wxCommandEvent & roEvtCmd   );
+    void  OnSimRun   ( wxCommandEvent & roEvtCmd   );
+    void  OnSimStop  ( wxCommandEvent & roEvtCmd   );
+    void  OnEditSchem( wxCommandEvent & roEvtCmd   );
+    void  OnViewData ( wxCommandEvent & roEvtCmd   );
+    void  OnSelSimEng( wxCommandEvent & roEvtCmd   );
+    void  OnPrefs    ( wxCommandEvent & roEvtCmd   );
+    void  OnManual   ( wxCommandEvent & roEvtCmd   );
+    void  OnAbout    ( wxCommandEvent & roEvtCmd   );
+    void  OnTbrEnter ( wxCommandEvent & roEvtCmd   );
+    void  OnSysExit  ( wxCloseEvent   & roEvtClose );
 
-    friend  class  AppGSpiceUI;
     friend  class  FileTasks;
 
     // In order to be able to react to a menu command, it must be given a
