@@ -2,7 +2,7 @@
 //                                HelpTasks.cpp                               *
 //                               ---------------                              *
 //  Started     : 03/06/2005                                                  *
-//  Last Update : 24/01/2008                                                  *
+//  Last Update : 04/09/2009                                                  *
 //  Copyright   : (C) 2005 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -22,9 +22,9 @@
 // The application icon
 #if defined( __WXGTK__ ) || defined( __WXMOTIF__ ) || defined( __WXMAC__ ) || \
     defined( __WXMGL__ ) || defined( __WXX11__ )
-  #include "icons/gspiceui-32x32.xpm"
-  #include "icons/html-close.xpm"
-  #include "icons/html-back.xpm"
+    #include "icons/gspiceui-32x32.xpm"
+    #include "icons/html-close.xpm"
+    #include "icons/html-back.xpm"
 #endif
 
 //*****************************************************************************
@@ -54,7 +54,7 @@ HelpTasks::HelpTasks( FrmMain * poFrmMain ) :
   m_poFrmMain = poFrmMain;
 
   // Get the global configuration object
-  m_poConfig = (wxConfig *) wxConfig::Get( );
+  m_poCfg = (wxConfig *) wxConfig::Get( );
 
   // Initialize the help viewer
   Initialize( );
@@ -72,6 +72,10 @@ HelpTasks::~HelpTasks( )
 
 void  HelpTasks::Initialize( void )
 {
+  // The next line just suppresses the following compiler warning :
+  //   ./icons/gspiceui-32x32.xpm:3: warning: gspiceui_xpm defined but not used
+  char  c1; c1 = gspiceui_xpm[ 0 ][ 0 ];
+
   // Set the frame icon
   SetIcon( wxICON( gspiceui ) );
 
@@ -146,11 +150,11 @@ void  HelpTasks::InitPosnSize( void )
   int  ix, iy, iw, ih;
 
   // Set the position and size from the configuration object
-  m_poConfig->SetPath( wxT("/Help") );
-  ix = m_poConfig->Read( wxT("PosnX"), 500 );
-  iy = m_poConfig->Read( wxT("PosnY"),   1 );
-  iw = m_poConfig->Read( wxT("SizeW"), 500 );
-  ih = m_poConfig->Read( wxT("SizeH"), 700 );
+  m_poCfg->SetPath( wxT("/Help") );
+  ix = m_poCfg->Read( wxT("PosnX"), 500 );
+  iy = m_poCfg->Read( wxT("PosnY"),   1 );
+  iw = m_poCfg->Read( wxT("SizeW"), 500 );
+  ih = m_poCfg->Read( wxT("SizeH"), 700 );
 
   if( ix>0 && iy>0 ) Move( ix, iy );
   if( iw>0 && ih>0 ) SetClientSize( iw, ih );
@@ -257,21 +261,37 @@ void  HelpTasks::About( void )
   wxString  os1;
   long      lStyle;
 
-  os1 << wxT("\n      " ) << APP_NAME << wxT("  -  ") << APP_VERSION << wxT("\n")
-      << wxT("                      Copyright (c) Mike Waters 2003\n\n")
-      << wxT("This application is intended to provide a GUI for various freely\n")
-      << wxT("available SPICE electronic circuit simulation engines:\n\n")
-      << wxT("               GNU-Cap\n")
-      << wxT("               NG-Spice\n\n")
-      << wxT("It is based on the ") << wxVERSION_STRING << wxT(" library and uses gNetList\n")
-      << wxT("to import schematic files and gWave to plot waveform data.\n\n")
-      << APP_NAME << wxT(" comes with ABSOLUTELY NO WARRANTY.\n")
-      << wxT("This is Free Software, and you are welcome to distribute it\n")
-      << wxT("under the terms of the GNU General Public License.\n");
+  os1 << wxT("\n                               " ) << APP_NAME
+      << wxT("\n                ")                 << APP_VERSION
+      << wxT("\n                    ")             << APP_COPYRIGHT
+      << wxT("\n\n")
+
+      << wxT("\nThis application is intended to provide a GUI for various")
+      << wxT("\nfreely available electronic circuit simulation engines :\n")
+      << wxT("\n                 - NG-Spice")
+      << wxT("\n                 - GNU-Cap\n")
+
+      << wxT("\nSchematic files are imported using gNetList and waveform     ")
+      << wxT("\ndata can be viewed using either ") << CLP_GWAVE << wxT(" or ")
+      << CLP_GAW << wxT(".\n")
+
+      << wxT("\nThis application is written in C++ and is based on the free")
+      << wxT("\nsoftware C++ library ") << wxVERSION_STRING << wxT(".\n")
+
+      << wxT("\n") << APP_NAME << wxT(" is free software; you can redistribute it")
+      << wxT("\nand/or modify it under the terms of the GNU Library")
+      << wxT("\nGeneral Public Licence as published by the Free Software")
+      << wxT("\nFoundation; either version 2 of the Licence, or (at your")
+      << wxT("\noption) any later version.\n")
+
+      << wxT("\n") << APP_NAME << wxT(" is distributed in the hope that it will be")
+      << wxT("\nuseful, but WITHOUT ANY WARRANTY; without even the")
+      << wxT("\nimplied warranty of MERCHANTABILITY or FITNESS FOR A")
+      << wxT("\nPARTICULAR PURPOSE.");
 
   lStyle = wxOK | wxICON_INFORMATION;
 
-  wxMessageBox( os1, wxT("About ") APP_NAME, lStyle, m_poFrmMain );
+  wxMessageBox( os1, wxT("About gSpiceUI"), lStyle, m_poFrmMain );
 }
 
 //*****************************************************************************
@@ -299,11 +319,12 @@ void  HelpTasks::OnClose( wxCommandEvent & roEvtCmd )
   // Save the frame size and position
   GetPosition( &ix, &iy );
   GetClientSize( &iw, &ih );
-  m_poConfig->Write( wxT("/Help/PosnX"), (long) ix );
-  m_poConfig->Write( wxT("/Help/PosnY"), (long) iy );
-  m_poConfig->Write( wxT("/Help/SizeW"), (long) iw );
-  m_poConfig->Write( wxT("/Help/SizeH"), (long) ih );
-  m_poConfig->Flush( );
+  m_poCfg->SetPath( wxT("/Help") );
+  m_poCfg->Write( wxT("PosnX"), (long) ix );
+  m_poCfg->Write( wxT("PosnY"), (long) iy );
+  m_poCfg->Write( wxT("SizeW"), (long) iw );
+  m_poCfg->Write( wxT("SizeH"), (long) ih );
+  m_poCfg->Flush( );
 
   Show( FALSE );  // Hide the frame
 
