@@ -2,7 +2,7 @@
 //                               NbkNgSpice.cpp                               *
 //                              ----------------                              *
 //  Started     : 08/05/2004                                                  *
-//  Last Update : 11/12/2007                                                  *
+//  Last Update : 13/10/2009                                                  *
 //  Copyright   : (C) 2004 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -36,11 +36,11 @@ END_EVENT_TABLE( )
 //   roPosn   - The notebook position
 //   roSize   - The notebook size
 
-NbkNgSpice::NbkNgSpice( wxWindow * poParent, wxWindowID oWinID )
-                   : NbkSimrBase( poParent, oWinID ), m_oDlgOptions( poParent )
+NbkNgSpice::NbkNgSpice( wxWindow * poParent, wxWindowID oWinID ) :
+                      NbkSimrBase( poParent, oWinID ), m_oDlgCfgOPT( poParent )
 {
   // Set the simulator engine type specifier
-  bSetSimrType( eSIMR_NGSPICE );
+  m_eSimEng = eSIMR_NGSPICE;
 
   // Create the various display objects
   m_poPnlNgSpiceDC = new PnlNgSpiceDC( this );
@@ -60,10 +60,10 @@ NbkNgSpice::NbkNgSpice( wxWindow * poParent, wxWindowID oWinID )
 // Default constructor.
 // (Used for two stage creation ie. must call Create( ) method.
 
-NbkNgSpice::NbkNgSpice( void ) : NbkSimrBase( ), m_oDlgOptions( this )
+NbkNgSpice::NbkNgSpice( void ) : NbkSimrBase( ), m_oDlgCfgOPT( this )
 {
   // Set the simulator engine type specifier
-  bSetSimrType( eSIMR_NGSPICE );
+  m_eSimEng = eSIMR_NGSPICE;
 }
 
 //*****************************************************************************
@@ -82,40 +82,47 @@ NbkNgSpice::~NbkNgSpice( )
 
 bool  NbkNgSpice::bClear( void )
 {
-  bool  bRtnValue=TRUE;
+  bool  bRtn=TRUE;
 
-  if( ! m_poPnlNgSpiceDC->bClear( ) ) bRtnValue = FALSE;
-  if( ! m_poPnlNgSpiceAC->bClear( ) ) bRtnValue = FALSE;
-  if( ! m_poPnlNgSpiceTR->bClear( ) ) bRtnValue = FALSE;
+  // Clear the base class
+  if( ! NbkSimrBase     ::bClear( ) ) bRtn = FALSE;
 
-  if( ! m_oDlgOptions    .bClear( ) ) bRtnValue = FALSE;
+  if( ! m_poPnlNgSpiceDC->bClear( ) ) bRtn = FALSE;
+  if( ! m_poPnlNgSpiceAC->bClear( ) ) bRtn = FALSE;
+  if( ! m_poPnlNgSpiceTR->bClear( ) ) bRtn = FALSE;
 
-  return( bRtnValue );
+  if( ! m_oDlgCfgOPT     .bClear( ) ) bRtn = FALSE;
+
+  return( bRtn );
 }
 
 //*****************************************************************************
 // Load information from a simulation object.
 //
 // Argument List :
-//   roSim - The simulation object
+//   roSimn - The simulation object
 //
 // Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  NbkNgSpice::bLoad( Simulation & roSim )
+bool  NbkNgSpice::bLoad( const SimnBase & roSimn )
 {
-  bool  bRtnValue=TRUE;
+  bool  bRtn=TRUE;
 
-  if( ! m_poPnlNgSpiceDC->bLoad( roSim ) )              bRtnValue = FALSE;
-  if( ! m_poPnlNgSpiceAC->bLoad( roSim ) )              bRtnValue = FALSE;
-  if( ! m_poPnlNgSpiceTR->bLoad( roSim ) )              bRtnValue = FALSE;
+  if( roSimn.eGetSimEng( ) != eSIMR_NGSPICE )            return( FALSE );
 
-  if( m_oDlgOptions.bSetCmd( roSim.rosGetOPTIONS( ) ) ) bRtnValue = FALSE;
+  SimnNgSpice & roSimnNgs = (SimnNgSpice &) roSimn;
 
-  if( ! bSetPage( roSim.eGetAnaType( ) ) )              bRtnValue = FALSE;
+  if( ! bSetPage( roSimnNgs.eGetAnaType( ) ) )           bRtn = FALSE;
 
-  return( bRtnValue );
+  if( ! m_poPnlNgSpiceDC->bLoad( roSimnNgs ) )           bRtn = FALSE;
+  if( ! m_poPnlNgSpiceAC->bLoad( roSimnNgs ) )           bRtn = FALSE;
+  if( ! m_poPnlNgSpiceTR->bLoad( roSimnNgs ) )           bRtn = FALSE;
+
+  if( ! m_oDlgCfgOPT.bSetValues( roSimnNgs.m_oCmdOPT ) ) bRtn = FALSE;
+
+  return( bRtn );
 }
 
 //*****************************************************************************
@@ -128,25 +135,52 @@ bool  NbkNgSpice::bLoad( Simulation & roSim )
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  NbkNgSpice::bSave( Simulation & roSim )
+bool  NbkNgSpice::bSave( SimnBase & roSimn )
 {
+  wxString  os1;
+
+  // Only proceed if this is an NG-Spice simulation object
+  if( roSimn.eGetSimEng( ) != eSIMR_NGSPICE ) return( FALSE );
+
+  SimnNgSpice & roSimnNgs = (SimnNgSpice &) roSimn;
+
+  // Clear the error string
+  NbkSimrBase::m_osErrMsg.Empty( );
+
+  // Create the analysis command/s
   switch( GetSelection( ) )
   {
     case 0 : // DC analysis
-      if( ! m_poPnlNgSpiceDC->bSave( roSim ) ) return( FALSE );
+      if( ! m_poPnlNgSpiceDC->bSave( roSimnNgs ) )
+        SetErrMsg( m_poPnlNgSpiceDC->rosGetErrMsg( ) );
       break;
-    case 1 : // AC analysis
-      if( ! m_poPnlNgSpiceAC->bSave( roSim ) ) return( FALSE );
-      break;
-    case 2 : // TR analysis
-      if( ! m_poPnlNgSpiceTR->bSave( roSim ) ) return( FALSE );
-      break;
-    default:                                   return( FALSE );
-  }
 
-  m_oDlgOptions.m_fTEMP = roSim.fGetTempC( );
-  m_oDlgOptions.bFormat( );
-  roSim.bSetOPTIONS( (wxString) m_oDlgOptions );
+    case 1 : // AC analysis
+      if( ! m_poPnlNgSpiceAC->bSave( roSimnNgs ) )
+        SetErrMsg( m_poPnlNgSpiceAC->rosGetErrMsg( ) );
+      break;
+
+    case 2 : // TR analysis
+      if( ! m_poPnlNgSpiceTR->bSave( roSimnNgs ) )
+        SetErrMsg( m_poPnlNgSpiceTR->rosGetErrMsg( ) );
+      break;
+
+    default:                                  return( FALSE );
+  }
+  if( ! bIsOk( ) )                            return( FALSE );
+
+  // Create the OPTIONS command
+  os1 = roSimnNgs.m_oCmdOPT.m_osTEMP;
+  m_oDlgCfgOPT.bGetValues( roSimnNgs.m_oCmdOPT );
+  roSimnNgs.m_oCmdOPT.m_osTEMP = os1;
+  roSimnNgs.m_oCmdOPT.bSetWidth( roSimnNgs.m_oCmdPR.iGetParaCnt( ) );
+  roSimnNgs.m_oCmdOPT.bFormat( );
+  if( ! roSimnNgs.m_oCmdOPT.bIsValid( ) )
+  {
+    os1 = wxT("OPTIONS command fault :\n\n  ");
+    SetErrMsg( os1 + roSimnNgs.m_oCmdOPT.rosGetErrMsg( ) );
+    return( FALSE );
+  }
 
   return( TRUE );
 }
@@ -155,23 +189,24 @@ bool  NbkNgSpice::bSave( Simulation & roSim )
 // Set the page to be displayed.
 //
 // Argument List :
-//   eType - The enumerated analysis type specifier
+//   eAnalysis - The enumerated analysis type specifier
 //
 // Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  NbkNgSpice::bSetPage( eAnaType eType )
+bool  NbkNgSpice::bSetPage( eCmdType eAnalysis )
 {
   int  iPage;
 
-  switch( eType )
+  switch( eAnalysis )
   {
-    case eANA_OP :
-    case eANA_DC : iPage = 0; break;
-    case eANA_AC : iPage = 1; break;
-    case eANA_TR : iPage = 2; break;
-    default :      return( FALSE );
+    case eCMD_NONE :
+    case eCMD_OP   :
+    case eCMD_DC   : iPage = 0; break;
+    case eCMD_AC   : iPage = 1; break;
+    case eCMD_TR   : iPage = 2; break;
+    default        : return( FALSE );
   }
 
   SetSelection( iPage ); // Specify the page to be displayed
@@ -183,28 +218,28 @@ bool  NbkNgSpice::bSetPage( eAnaType eType )
 // Set the page to be displayed.
 //
 // Argument List :
-//   psType - The two letter analysis type specifier (case ignored)
+//   psAnalysis - The two letter analysis type specifier (case ignored)
 //
 // Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  NbkNgSpice::bSetPage( const wxChar * psType )
+bool  NbkNgSpice::bSetPage( const wxChar * psAnalysis )
 {
-  eAnaType  eType=eANA_NONE;
-  wxString  osType;
+  eCmdType  eAnalysis=eCMD_NONE;
+  wxString  osAnalysis;
 
-  osType = wxString( psType ).Upper( );
+  osAnalysis = wxString( psAnalysis ).Upper( );
 
-  if( osType.Length( ) == 2 )
+  if( osAnalysis.Length( ) == 2 )
   {
-         if( osType == wxT("OP") ) eType = eANA_DC;
-    else if( osType == wxT("DC") ) eType = eANA_DC;
-    else if( osType == wxT("AC") ) eType = eANA_AC;
-    else if( osType == wxT("TR") ) eType = eANA_TR;
+    if(      osAnalysis == wxT("OP") ) eAnalysis = eCMD_DC;
+    else if( osAnalysis == wxT("DC") ) eAnalysis = eCMD_DC;
+    else if( osAnalysis == wxT("AC") ) eAnalysis = eCMD_AC;
+    else if( osAnalysis == wxT("TR") ) eAnalysis = eCMD_TR;
   }
 
-  return( bSetPage( eType ) );
+  return( bSetPage( eAnalysis ) );
 }
 
 //*****************************************************************************
@@ -220,10 +255,10 @@ const wxString & NbkNgSpice::rosGetPage( void )
 
   switch( eGetPage( ) )
   {
-    case eANA_DC : osPage = wxT("dc"); break;
-    case eANA_AC : osPage = wxT("ac"); break;
-    case eANA_TR : osPage = wxT("tr"); break;
-    default:       osPage.Empty( );
+    case eCMD_DC : osPage = wxT("dc"); break;
+    case eCMD_AC : osPage = wxT("ac"); break;
+    case eCMD_TR : osPage = wxT("tr"); break;
+    default      : osPage.Empty( );
   }
 
   return( osPage );
@@ -236,16 +271,16 @@ const wxString & NbkNgSpice::rosGetPage( void )
 //   Success - The enumerated analysis specifier
 //   Failure - Simulation::eANA_NONE
 
-eAnaType  NbkNgSpice::eGetPage( void )
+eCmdType  NbkNgSpice::eGetPage( void )
 {
-  eAnaType  ePage;
+  eCmdType  ePage;
 
   switch( GetSelection( ) )
   {
-    case 0 :  ePage = eANA_DC; break;
-    case 1 :  ePage = eANA_AC; break;
-    case 2 :  ePage = eANA_TR; break;
-    default : ePage = eANA_NONE;
+    case  0 : ePage = eCMD_DC; break;
+    case  1 : ePage = eCMD_AC; break;
+    case  2 : ePage = eCMD_TR; break;
+    default : ePage = eCMD_NONE;
   }
 
   return( ePage );
@@ -264,26 +299,26 @@ eAnaType  NbkNgSpice::eGetPage( void )
 void  NbkNgSpice::OnBtnOptions( wxCommandEvent & roEvtCmd )
 {
   PnlAnaBase * poPnlAna;
-  double       df1;
+  wxString     os1;
   int          i1;
 
   // Set the temperature in the OPTIONS dialog
   poPnlAna = (PnlAnaBase *) GetPage( GetSelection( ) );
-  if( poPnlAna->bIsCreatedTemp( ) )
+  if( poPnlAna->bIsCreated( PnlAnaBase::eCTLGRP_TEMP ) )
   {
-    df1 = poPnlAna->m_oPnlTemp.dfGetValue( );
-    m_oDlgOptions.bSetValue( DlgNgSpiceOPT::ID_PNL_TEMP, (float) df1 );
+    os1 = poPnlAna->m_oPnlTemp.rosGetValue( );
+    m_oDlgCfgOPT.bSetValue( DlgNgsCfgOPT::ID_PNL_TEMP, os1 );
   }
 
   // Display the OPTIONS dialog
-  m_oDlgOptions.CenterOnParent( );
-  i1 = m_oDlgOptions.ShowModal( );
+  m_oDlgCfgOPT.CenterOnParent( );
+  i1 = m_oDlgCfgOPT.ShowModal( );
 
   // Set the temperature in the analysis panel
-  if( i1==wxID_OK && poPnlAna->bIsCreatedTemp( ) )
+  if( poPnlAna->bIsCreated( PnlAnaBase::eCTLGRP_TEMP ) && i1==wxID_OK )
   {
-    df1 = m_oDlgOptions.dfGetValue( DlgNgSpiceOPT::ID_PNL_TEMP );
-    poPnlAna->m_oPnlTemp.bSetValue( df1 );
+    os1 = m_oDlgCfgOPT.rosGetValue( DlgNgsCfgOPT::ID_PNL_TEMP );
+    poPnlAna->m_oPnlTemp.bSetValue( os1 );
   }
 }
 
