@@ -5,7 +5,7 @@
 //                panels for the different analyses provided by NG-Spice      *
 //                electronic circuit simulator.                               *
 //  Started     : 08/05/2004                                                  *
-//  Last Update : 05/10/2007                                                  *
+//  Last Update : 30/06/2009                                                  *
 //  Copyright   : (C) 2004 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -28,12 +28,13 @@
 // wxWindows Includes
 
 #include <wx/wx.h>
+#include <wx/tooltip.h> // ???
 
 // Application Includes
 
 #include "TypeDefs.hpp"
 #include "base/NbkSimrBase.hpp"
-#include "ngspice/dialogs/DlgNgSpiceOPT.hpp"
+#include "ngspice/dialogs/DlgNgsCfgOPT.hpp"
 #include "ngspice/panels/PnlNgSpiceDC.hpp"
 #include "ngspice/panels/PnlNgSpiceAC.hpp"
 #include "ngspice/panels/PnlNgSpiceTR.hpp"
@@ -53,7 +54,7 @@ class NbkNgSpice : public NbkSimrBase
     PnlNgSpiceTR * m_poPnlNgSpiceTR;
 
     // OPTIONS line setup dialog
-    DlgNgSpiceOPT  m_oDlgOptions;
+    DlgNgsCfgOPT   m_oDlgCfgOPT;
 
   public :
 
@@ -63,14 +64,14 @@ class NbkNgSpice : public NbkSimrBase
 
     virtual  bool  bClear( void );
 
-    virtual  bool  bLoad( Simulation & roSim );
-    virtual  bool  bSave( Simulation & roSim );
+    virtual  bool  bLoad( const SimnBase & roSimn );
+    virtual  bool  bSave(       SimnBase & roSimn );
 
-    virtual  bool  bSetPage( const wxChar * psType );
-    virtual  bool  bSetPage( eAnaType eType );
+    virtual  bool  bSetPage( const wxChar * psAnalysis );
+    virtual  bool  bSetPage(       eCmdType  eAnalysis );
 
     virtual  const  wxString & rosGetPage( void );
-    virtual         eAnaType     eGetPage( void );
+    virtual         eCmdType     eGetPage( void );
 
     // Event handlers
     void  OnBtnOptions( wxCommandEvent & roEvtCmd );
