@@ -1,10 +1,10 @@
 //*****************************************************************************
 //                              CmdNgSpiceAC.cpp                              *
 //                             ------------------                             *
-//  Started     : 11/10/2007                                                  *
-//  Last Update : 21/02/2008                                                  *
-//  Copyright   : (C) 2007 by M.S.Waters                                      *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Started     : 11/10/2007                                                   *
+// Last Update : 14/10/2009                                                   *
+// Copyright   : (C) 2007 by M.S.Waters                                       *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -33,6 +33,71 @@ CmdNgSpiceAC::~CmdNgSpiceAC( )
 {
 }
 
+//*****************************************************************************
+// Check that the object attributes are valid.
+//
+// Return Values :
+//   TRUE  - Success
+//   FALSE - Failure
+
+bool  CmdNgSpiceAC::bValidate( void )
+{
+  double  df1, df2, df3;
+
+  CmdBase::bValidate( );
+
+  // Check the sweep start and stop values
+  if( ! ConvertType::bStrToDFlt( m_osStart, &df1 ) )
+    SetErrMsg( wxT("Invalid sweep start value.") );
+  if( ! ConvertType::bStrToDFlt( m_osStop,  &df2 ) )
+    SetErrMsg( wxT("Invalid sweep stop value.") );
+  if( df2 < df1 )
+    SetErrMsg( wxT("Start value greater than stop value.") );
+
+  // Check the sweep step value and sweep scale
+  if( ! ConvertType::bStrToDFlt( m_osStep, &df3 ) )
+    SetErrMsg( wxT("Invalid sweep step value.") );
+  if( df3 <= 0.0 )
+  SetErrMsg( wxT("Step value less than or equal to zero.") );
+  switch( m_eScale )
+  {
+    case eSCALE_LIN :
+      if( df1!=df2 && df3>fabs( df2 - df1 ) )
+        SetErrMsg( wxT("Step value is greater than sweep range.") );
+      break;
+    case eSCALE_DEC :
+    case eSCALE_OCT :
+      break;
+    default         :
+      SetErrMsg( wxT("Invalid step scale value.") );
+  }
+
+  return( bIsValid( ) );
+}
+
+//*****************************************************************************
+// Clear the object attributes.
+//
+// Return Values :
+//   TRUE  - Success
+//   FALSE - Failure
+
+bool  CmdNgSpiceAC::bClear( void )
+{
+  CmdBase::bClear( );
+
+  m_eSimEng  = eSIMR_NGSPICE;
+  m_eCmdType = eCMD_AC;
+
+  m_osStart  = wxT("1.0K");
+  m_osStop   = wxT("100.0K");
+  m_osStep   = wxT("10");
+
+  m_eScale   = eSCALE_DEC;
+
+  return( TRUE );
+}
+
 //*****************************************************************************
 // Parse the command string.
 //
@@ -54,42 +119,39 @@ bool  CmdNgSpiceAC::bParse( void )
   // Clear the object attributes
   os1 = *this;
   bClear( );
-  *this = os1;
+  assign( os1 );
 
   // Tokenize the command string
   ostk1.SetString( *this );
-  if( ostk1.CountTokens( ) != 5 ) return( FALSE );
+  if( ostk1.CountTokens( ) != 5 ) return( bValidate( ) );
 
   // Check command type
   os1 = ostk1.GetNextToken( ).Left( 3 ).Upper( );
-  if( os1 != wxT(".AC") )         return( FALSE );
-  m_osName = wxT("AC");
-
-  m_bIsOk = TRUE;
+  if( os1 != wxT(".AC") )         return( bValidate( ) );
 
   // Extract the sweep type: linear or log
   os1 = ostk1.GetNextToken( ).Upper( );
   if(      os1 == wxT("LIN") ) m_eScale = eSCALE_LIN;
   else if( os1 == wxT("DEC") ) m_eScale = eSCALE_DEC;
   else if( os1 == wxT("OCT") ) m_eScale = eSCALE_OCT;
-  else                            m_bIsOk = FALSE;
+  else                            return( bValidate( ) );
 
   // Extract the step count
   os1 = ostk1.GetNextToken( );
-  if( ConvertType::bStrToInt( os1, &li1 ) ) m_fStep  = (float) li1;
-  else                            m_bIsOk = FALSE;
+  if( ConvertType::bStrToLong( os1, &li1 ) ) m_osStep  = os1;
+  else                            return( bValidate( ) );
 
   // Extract the start frequency
   os1 = ostk1.GetNextToken( );
-  if( ConvertType::bStrToFlt( os1, &df1 ) ) m_fStart = (float) df1;
-  else                            m_bIsOk = FALSE;
+  if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osStart = os1;
+  else                            return( bValidate( ) );
 
   // Extract the stop frequency
   os1 = ostk1.GetNextToken( );
-  if( ConvertType::bStrToFlt( os1, &df1 ) ) m_fStop  = (float) df1;
-  else                            m_bIsOk = FALSE;
+  if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osStop  = os1;
+  else                            return( bValidate( ) );
 
-  return( m_bIsOk );
+  return( bValidate( ) );
 }
 
 //*****************************************************************************
@@ -103,8 +165,6 @@ bool  CmdNgSpiceAC::bFormat( void )
 {
   wxString  osCmd, os1;
 
-  m_bIsOk = FALSE;
-
   osCmd = wxT(".AC");
 
   switch( m_eScale )
@@ -112,42 +172,71 @@ bool  CmdNgSpiceAC::bFormat( void )
     case eSCALE_LIN : osCmd << wxT(" LIN"); break;
     case eSCALE_DEC : osCmd << wxT(" DEC"); break;
     case eSCALE_OCT : osCmd << wxT(" OCT"); break;
-    default         :                                         return( FALSE );
+    default         : break;
   }
 
-  osCmd << wxT(' ') << (int) lroundf( m_fStep );
+  osCmd << wxT(' ') << m_osStep;
+  osCmd << wxT(' ') << m_osStart;
+  osCmd << wxT(' ') << m_osStop;
 
-  if( ! ConvertType::bFltToStrEng( (double) m_fStart, os1 ) ) return( FALSE );
-  osCmd << wxT(' ') << os1;
+  assign( osCmd );
 
-  if( ! ConvertType::bFltToStrEng( (double) m_fStop,  os1 ) ) return( FALSE );
-  osCmd << wxT(' ') << os1;
-
-  *this = osCmd;
-
-  m_bIsOk = TRUE;
-
-  return( m_bIsOk );
+  return( bValidate( ) );
 }
 
 //*****************************************************************************
-// Clear the object attributes.
+// Copy the contents of a CmdGnuCapAC object.
+//
+// Argument List :
+//   poCmdAC - A pointer to a CmdNgSpiceAC object
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   A pointer to this object
 
-bool  CmdNgSpiceAC::bClear( void )
+CmdNgSpiceAC & CmdNgSpiceAC::operator = ( const CmdGnuCapAC & roCmdAC )
 {
-  CmdBase::bClear( );
+  (CmdBase &) *this = (CmdBase &) roCmdAC;
 
-  m_fStart = -FLT_MAX;
-  m_fStop  = -FLT_MAX;
-  m_fStep  = -FLT_MIN;
+  m_osStart = roCmdAC.m_osStart;
+  m_osStop  = roCmdAC.m_osStop;
+  m_osStep  = roCmdAC.m_osStep;
+  m_eScale  = roCmdAC.m_eScale;
 
-  m_eScale = eSCALE_NONE;
+  // NG-Spice doesn't support logarithmic scaling
+  if( m_eScale == eSCALE_LOG ) m_eScale = eSCALE_DEC;
 
-  return( TRUE );
+  bFormat( );
+
+  return( *this );
+}
+
+//*****************************************************************************
+// Print the object attributes.
+//
+// Argument List :
+//   psPrefix - A prefix to every line displayed (usually just spaces)
+
+void  CmdNgSpiceAC::Print( const wxString & rosPrefix )
+{
+  CmdBase::Print( rosPrefix + wxT("CmdBase::") );
+
+  cout << rosPrefix .mb_str( ) << "m_osStart : "
+       << m_osStart .mb_str( ) << '\n';
+  cout << rosPrefix .mb_str( ) << "m_osStop  : "
+       << m_osStop  .mb_str( ) << '\n';
+  cout << rosPrefix .mb_str( ) << "m_osStep  : "
+       << m_osStep  .mb_str( ) << '\n';
+
+  cout << rosPrefix .mb_str( ) << "m_eScale  : ";
+  switch( m_eScale )
+  {
+    case eSCALE_LIN  : cout << "eSCALE_LIN\n";  break;
+    case eSCALE_LOG  : cout << "eSCALE_LOG\n";  break;
+    case eSCALE_DEC  : cout << "eSCALE_DEC\n";  break;
+    case eSCALE_OCT  : cout << "eSCALE_OCT\n";  break;
+    case eSCALE_NONE : cout << "eSCALE_NONE\n"; break;
+    default :          cout << "Invalid\n";     break;
+  }
 }
 
 //*****************************************************************************
@@ -188,7 +277,7 @@ int  main( int argc, char * argv[ ] )
 
   // Display the utility banner
   cout << "\n  Class CmdNgSpiceAC Test Utility"
-       << "\n     Version 1.00 (01/02/2008)\n";
+       << "\n     Version 1.01 (04/06/2009)\n";
 
   // Create a GNU-CAP AC command object
   CmdNgSpiceAC  oCmd_AC;
@@ -198,10 +287,10 @@ int  main( int argc, char * argv[ ] )
 
   // Set things up for a formatter test
   oCmd_AC.bClear( );
-  oCmd_AC.m_fStart = 1.0E3;
-  oCmd_AC.m_fStop  = 300.0E3;
-  oCmd_AC.m_fStep  = 30;
-  oCmd_AC.m_eScale = eSCALE_DEC;
+  oCmd_AC.m_osStart = wxT("1.00K");
+  oCmd_AC.m_osStop  = wxT("300.00K");
+  oCmd_AC.m_osStep  = wxT("30");
+  oCmd_AC.m_eScale  = eSCALE_DEC;
   cout << "\nRun Formatter    : " << ( oCmd_AC.bFormat( ) ? "OK" : "FAULT" );
   cout << "\nTest Cmd Format  : " << ( oCmd_AC == osCmd   ? "OK" : "FAULT" );
   cout << "\nExample Command  : " << osCmd  .mb_str( );
@@ -209,7 +298,7 @@ int  main( int argc, char * argv[ ] )
 
   // Set things up for a parser test
   oCmd_AC.bClear( );
-  oCmd_AC = osCmd;
+  oCmd_AC.bSetString( osCmd );
   cout << "\nRun Parser       : " << ( oCmd_AC.bParse( ) ? "OK" : "FAULT" );
   oCmd_AC.bFormat( );
   cout << "\nTest Cmd Format  : " << ( oCmd_AC == osCmd  ? "OK" : "FAULT" );
