@@ -1,12 +1,12 @@
 //*****************************************************************************
 //                              CmdNgSpiceAC.hpp                              *
 //                             ------------------                             *
-//  Description : This class contains values associated with the NG-Spice     *
-//                AC command. It inherits from the class CmdBase.             *
-//  Started     : 11/10/2007                                                  *
-//  Last Update : 11/12/2007                                                  *
-//  Copyright   : (C) 2007 by M.S.Waters                                      *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Description : This class contains values associated with the NG-Spice      *
+//               AC command. It inherits from the class CmdBase.              *
+// Started     : 11/10/2007                                                   *
+// Last Update : 13/05/2009                                                   *
+// Copyright   : (C) 2007 by M.S.Waters                                       *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -33,33 +33,40 @@
 
 // Application Includes
 
-#include "TypeDefs.hpp"
 #include "base/CmdBase.hpp"
+#include "gnucap/commands/CmdGnuCapAC.hpp"
 #include "utility/ConvertType.hpp"
 
+struct CmdGnuCapAC;
+
 // Local Macro and Constant Declarations
 
 //*****************************************************************************
 
 struct CmdNgSpiceAC : public CmdBase
 {
+  private :
+
+    virtual  bool  bValidate( void );
+
   public :
 
-    float       m_fStart;  // The sweep start value
-    float       m_fStop;   // The sweep stop  value
-    float       m_fStep;   // The sweep step  value
-    eScaleType  m_eScale;  // The sweep scale type
+    wxString    m_osStart;  // The sweep start value
+    wxString    m_osStop;   // The sweep stop  value
+    wxString    m_osStep;   // The sweep step  value
+    eScaleType  m_eScale;   // The sweep scale type
 
               CmdNgSpiceAC( void );
     virtual  ~CmdNgSpiceAC( );
 
-    bool  bClear( void );
+    virtual  bool  bClear   ( void );
 
     virtual  bool  bParse ( void );
     virtual  bool  bFormat( void );
 
-    wxString & operator = ( const wxString & ros )
-                { *((wxString *) this) = ros; return( *((wxString *) this) ); }
+    CmdNgSpiceAC & operator = ( const CmdGnuCapAC & roCmdAC );
+
+    void  Print( const wxString & rosPrefix=wxT("  ") );
 };
 
 //*****************************************************************************
