@@ -1,10 +1,10 @@
 //*****************************************************************************
 //                              CmdNgSpiceDC.cpp                              *
 //                             ------------------                             *
-//  Started     : 21/08/2007                                                  *
-//  Last Update : 22/02/2008                                                  *
-//  Copyright   : (C) 2007 by M.S.Waters                                      *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Started     : 21/08/2007                                                   *
+// Last Update : 14/10/2009                                                   *
+// Copyright   : (C) 2007 by M.S.Waters                                       *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -33,6 +33,63 @@ CmdNgSpiceDC::~CmdNgSpiceDC( )
 {
 }
 
+//*****************************************************************************
+// Check that the object attributes are valid.
+//
+// Return Values :
+//   TRUE  - Success
+//   FALSE - Failure
+
+bool  CmdNgSpiceDC::bValidate( void )
+{
+  double  df1, df2, df3;
+
+  CmdBase::bValidate( );
+
+  // Check the sweep start and stop values
+  if( ! ConvertType::bStrToDFlt( m_osStart, &df1 ) )
+    SetErrMsg( wxT("Invalid sweep start value.") );
+  if( ! ConvertType::bStrToDFlt( m_osStop,  &df2 ) )
+    SetErrMsg( wxT("Invalid sweep stop value.") );
+  if( df2 < df1 )
+    SetErrMsg( wxT("Start value greater than stop value.") );
+
+  // Check the sweep step value and sweep scale
+  if( ! ConvertType::bStrToDFlt( m_osStep, &df3 ) )
+    SetErrMsg( wxT("Invalid sweep step value.") );
+  if( df3 <= 0.0 )
+    SetErrMsg( wxT("Step value less than or equal to zero.") );
+
+  // Check the component to be used as the sweep source
+  if( m_osSource.IsEmpty( ) && m_osSource!=wxT("TEMP") )
+    SetErrMsg( wxT("No source component has been selected.") );
+
+  return( bIsValid( ) );
+}
+
+//*****************************************************************************
+// Clear the object attributes.
+//
+// Return Values :
+//   TRUE  - Success
+//   FALSE - Failure
+
+bool  CmdNgSpiceDC::bClear( void )
+{
+  CmdBase::bClear( );
+
+  m_eSimEng  = eSIMR_NGSPICE;
+  m_eCmdType = eCMD_DC;
+
+  m_osStart  = wxT("0.0");
+  m_osStop   = wxT("100.0");
+  m_osStep   = wxT("10.0");
+
+  m_osSource = wxT("None");
+
+  return( TRUE );
+}
+
 //*****************************************************************************
 // Parse the command string.
 //
@@ -52,39 +109,36 @@ bool  CmdNgSpiceDC::bParse( void )
   // Clear the object attributes
   os1 = *this;
   bClear( );
-  *this = os1;
+  assign( os1 );
 
   // Tokenize the command string
   ostk1.SetString( *this );
-  if( ostk1.CountTokens( ) != 5 ) return( FALSE );
+  if( ostk1.CountTokens( ) != 5 ) return( bValidate( ) );
 
   // Check command type
   os1 = ostk1.GetNextToken( ).Left( 3 ).Upper( );
   if( os1 != wxT(".DC") )         return( FALSE );
-  m_osName = wxT("DC");
 
-  m_bIsOk = TRUE;
-
-  // Extract the sweep type: a signal source or temperature
+  // Extract the sweep type : a signal source or temperature
   m_osSource = ostk1.GetNextToken( );
-  if( m_osSource.IsEmpty( ) )     m_bIsOk = FALSE;
+  if( m_osSource.IsEmpty( ) )     return( bValidate( ) );
 
   // Extract the start value
   os1 = ostk1.GetNextToken( );
-  if( ConvertType::bStrToFlt( os1, &df1 ) ) m_fStart = (float) df1;
-  else                            m_bIsOk = FALSE;
+  if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osStart = os1;
+  else                            return( bValidate( ) );
 
   // Extract the stop value
   os1 = ostk1.GetNextToken( );
-  if( ConvertType::bStrToFlt( os1, &df1 ) ) m_fStop  = (float) df1;
-  else                            m_bIsOk = FALSE;
+  if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osStop  = os1;
+  else                            return( bValidate( ) );
 
   // Extract the step increment
   os1 = ostk1.GetNextToken( );
-  if( ConvertType::bStrToFlt( os1, &df1 ) ) m_fStep  = (float) df1;
-  else                            m_bIsOk = FALSE;
+  if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osStep  = os1;
+  else                            return( bValidate( ) );
 
-  return( m_bIsOk );
+  return( bValidate( ) );
 }
 
 //*****************************************************************************
@@ -96,67 +150,89 @@ bool  CmdNgSpiceDC::bParse( void )
 
 bool  CmdNgSpiceDC::bFormat( void )
 {
-  wxString  osCmd, os1;
-
-  m_bIsOk = FALSE;
+  wxString  osCmd;
 
   // Set the command name
   osCmd = wxT(".DC");
-  if( m_osName.IsEmpty( ) ) m_osName = wxT("DC");
 
   // Set signal source
   osCmd << wxT(' ') << m_osSource;
 
   // Set sweep parameters
-  if( ! ConvertType::bFltToStrEng( (double) m_fStart, os1 ) ) return( FALSE );
-  osCmd << wxT(' ') << os1;
-  if( ! ConvertType::bFltToStrEng( (double) m_fStop,  os1 ) ) return( FALSE );
-  osCmd << wxT(' ') << os1;
-  if( ! ConvertType::bFltToStrEng( (double) m_fStep,  os1 ) ) return( FALSE );
-  osCmd << wxT(' ') << os1;
+  osCmd << wxT(' ') << m_osStart;
+  osCmd << wxT(' ') << m_osStop;
+  osCmd << wxT(' ') << m_osStep;
 
-  *this = osCmd;
+  assign( osCmd );
 
-  m_bIsOk = TRUE;
-
-  return( m_bIsOk );
+  return( bValidate( ) );
 }
 
 //*****************************************************************************
-// Clear the object attributes.
+// Copy the contents of a CmdGnuCapOP object.
+//
+// Argument List :
+//   roCmdOP - A reference to a CmdGnuCapOP object
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   A reference to this object
 
-bool  CmdNgSpiceDC::bClear( void )
+CmdNgSpiceDC & CmdNgSpiceDC::operator = ( const CmdGnuCapOP & roCmdOP )
 {
-  CmdBase::bClear( );
+  (CmdBase &) *this = (CmdBase &) roCmdOP;
 
-  m_fStart = -FLT_MAX;
-  m_fStop  = -FLT_MAX;
-  m_fStep  = -FLT_MAX;
+  m_osStart  = roCmdOP.m_osStart;
+  m_osStop   = roCmdOP.m_osStop;
+  m_osStep   = roCmdOP.m_osStep;
+  m_osSource = wxT("TEMP");
 
-  m_osSource.Empty( );
+  bFormat( );
 
-  return( TRUE );
+  return( *this );
+}
+
+//*****************************************************************************
+// Copy the contents of a CmdGnuCapDC object.
+//
+// Argument List :
+//   roCmdDC - A reference to a CmdGnuCapDC object
+//
+// Return Values :
+//   A reference to this object
+
+CmdNgSpiceDC & CmdNgSpiceDC::operator = ( const CmdGnuCapDC & roCmdDC )
+{
+  (CmdBase &) *this = (CmdBase &) roCmdDC;
+
+  m_osStart  = roCmdDC.m_osStart;
+  m_osStop   = roCmdDC.m_osStop;
+  m_osStep   = roCmdDC.m_osStep;
+  m_osSource = roCmdDC.m_osSource;
+
+  bFormat( );
+
+  return( *this );
 }
 
 //*****************************************************************************
 // Print the object attributes.
 //
 // Argument List :
-//   psPrefix - A prefix to every line displayed (usually just spaces)
+//   rosPrefix - A prefix to every line displayed (usually just spaces)
 
-void  CmdNgSpiceDC::Print( const char * psPrefix )
+void  CmdNgSpiceDC::Print( const wxString & rosPrefix )
 {
-  CmdBase::Print( psPrefix );
+  CmdBase::Print( rosPrefix + wxT("CmdBase::") );
 
-  cout << psPrefix << "m_fStart    : " << m_fStart << '\n';
-  cout << psPrefix << "m_fStop     : " << m_fStop << '\n';
-  cout << psPrefix << "m_fStep     : " << m_fStep << '\n';
+  cout << rosPrefix.mb_str( ) << "m_osStart  : "
+       << m_osStart.mb_str( ) << '\n';
+  cout << rosPrefix.mb_str( ) << "m_osStop   : "
+       << m_osStop .mb_str( ) << '\n';
+  cout << rosPrefix.mb_str( ) << "m_osStep   : "
+       << m_osStep .mb_str( ) << '\n';
 
-  cout << psPrefix << "m_osSource  : " << m_osSource.mb_str( ) << '\n';
+  cout << rosPrefix .mb_str( ) << "m_osSource : "
+       << m_osSource.mb_str( ) << '\n';
 }
 
 //*****************************************************************************
@@ -197,7 +273,7 @@ int  main( int argc, char * argv[ ] )
 
   // Display the utility banner
   cout << "\n  Class CmdNgSpiceDC Test Utility"
-       << "\n     Version 1.00 (30/01/2008)\n";
+       << "\n     Version 1.01 (04/06/2009)\n";
 
   // Create a NG-SPICE DC command object
   CmdNgSpiceDC  oCmd_DC;
@@ -207,9 +283,9 @@ int  main( int argc, char * argv[ ] )
 
   // Set things up for a formatter test
   oCmd_DC.bClear( );
-  oCmd_DC.m_fStart   = 0.0;
-  oCmd_DC.m_fStop    = 100.0E-3;
-  oCmd_DC.m_fStep    = 10.0E-3;
+  oCmd_DC.m_osStart  = wxT("0.00");
+  oCmd_DC.m_osStop   = wxT("100.00m");
+  oCmd_DC.m_osStep   = wxT("10.00m");
   oCmd_DC.m_osSource = wxT("Vin");
   cout << "\nRun Formatter    : " << ( oCmd_DC.bFormat( ) ? "OK" : "FAULT" );
   cout << "\nTest Cmd Format  : " << ( oCmd_DC == osCmd   ? "OK" : "FAULT" );
@@ -218,7 +294,7 @@ int  main( int argc, char * argv[ ] )
 
   // Set things up for a parser test
   oCmd_DC.bClear( );
-  oCmd_DC = osCmd;
+  oCmd_DC.bSetString( osCmd );
   cout << "\nRun Parser       : " << ( oCmd_DC.bParse( ) ? "OK" : "FAULT" );
   oCmd_DC.bFormat( );
   cout << "\nTest Cmd Format  : " << ( oCmd_DC == osCmd  ? "OK" : "FAULT" );
