@@ -1,12 +1,12 @@
 //*****************************************************************************
 //                              CmdNgSpiceDC.hpp                              *
 //                             ------------------                             *
-//  Description : This class contains values associated with the NG-Spice DC  *
-//                command. It inherits from the class CmdBase.                *
-//  Started     : 23/08/2006                                                  *
-//  Last Update : 29/01/2008                                                  *
-//  Copyright   : (C) 2006 by M.S.Waters                                      *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Description : This class contains values associated with the NG-Spice      *
+//               DC command. It inherits from the class CmdBase.              *
+// Started     : 23/08/2006                                                   *
+// Last Update : 13/05/2009                                                   *
+// Copyright   : (C) 2006 by M.S.Waters                                       *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -36,33 +36,42 @@ using  namespace  std;
 // Application Includes
 
 #include "base/CmdBase.hpp"
+#include "gnucap/commands/CmdGnuCapOP.hpp"
+#include "gnucap/commands/CmdGnuCapDC.hpp"
 #include "utility/ConvertType.hpp"
 
+struct CmdGnuCapOP;
+struct CmdGnuCapDC;
+
 // Local Macro and Constant Declarations
 
 //*****************************************************************************
 
 struct CmdNgSpiceDC : public CmdBase
 {
+  private :
+
+    virtual  bool  bValidate( void );
+
   public :
 
-    float     m_fStart;    // Sweep start value
-    float     m_fStop;     // Sweep stop  value
-    float     m_fStep;     // Sweep step  value
+    wxString  m_osStart;   // Sweep start value
+    wxString  m_osStop;    // Sweep stop  value
+    wxString  m_osStep;    // Sweep step  value
     wxString  m_osSource;  // Sweep source
 
               CmdNgSpiceDC( void );
     virtual  ~CmdNgSpiceDC( );
 
-    bool  bClear( void );
+    virtual  bool  bClear   ( void );
 
     virtual  bool  bParse ( void );
     virtual  bool  bFormat( void );
 
-    wxString & operator = ( const wxString & ros )
-                { *((wxString *) this) = ros; return( *((wxString *) this) ); }
+    CmdNgSpiceDC & operator = ( const CmdGnuCapOP & roCmdOP );
+    CmdNgSpiceDC & operator = ( const CmdGnuCapDC & roCmdDC );
 
-    void  Print( const char * psPrefix="" );
+    void  Print( const wxString & rosPrefix=wxT("  ") );
 };
 
 //*****************************************************************************
