@@ -1,10 +1,10 @@
 //*************************************"***************************************
 //                              CmdNgSpicePR.cpp                              *
 //                             ------------------                             *
-//  Started     : 16/10/2007                                                  *
-//  Last Update : 22/02/2008                                                  *
-//  Copyright   : (C) 2007 by M.S.Waters                                      *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Started     : 16/10/2007                                                   *
+// Last Update : 07/10/2009                                                   *
+// Copyright   : (C) 2007 by M.S.Waters                                       *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -33,6 +33,82 @@ CmdNgSpicePR::~CmdNgSpicePR( )
 {
 }
 
+//*****************************************************************************
+// Check that the object attributes are valid.
+//
+// Return Values :
+//   TRUE  - Success
+//   FALSE - Failure
+
+bool  CmdNgSpicePR::bValidate( void )
+{
+  CmdBase::bValidate( );
+
+  if( m_osaNodes.GetCount( )<=0 && m_osaCpnts.GetCount( )<=0 )
+    SetErrMsg( wxT("No components or nodes have been selected.") );
+  if( ! m_bParmtrs[ ePAR_VLT ] )
+    SetErrMsg( wxT("No parameters selected.") );
+
+  return( bIsValid( ) );
+}
+
+//*****************************************************************************
+// Clear the object attributes.
+//
+// Return Values :
+//   TRUE  - Success
+//   FALSE - Failure
+
+bool  CmdNgSpicePR::bClear( void )
+{
+  int  i1;
+
+  CmdBase::bClear( );
+
+  m_eSimEng  = eSIMR_NGSPICE;
+  m_eCmdType = eCMD_PR;
+
+  m_eAnaType = eCMD_NONE;
+
+  m_osaNodes.Empty( );
+  m_osaCpnts.Empty( );
+
+  for( i1=(int)ePAR_FST; i1<=(int)ePAR_LST; i1++ ) m_bParmtrs[ i1 ] = FALSE;
+  for( i1=(int)eCPX_FST; i1<=(int)eCPX_LST; i1++ ) m_bCpxPrts[ i1 ] = FALSE;
+
+  return( TRUE );
+}
+
+//*****************************************************************************
+// Set the analysis type.
+//
+// Argument List :
+//   eAnaType - An analysis command type
+//
+// Return Values :
+//   TRUE  - Success
+//   FALSE - Failure
+
+bool  CmdNgSpicePR::bSetAnaType( eCmdType eAnaType )
+{
+  // Does anything actually need to be done?
+  if( eAnaType == m_eAnaType ) return( TRUE );
+
+  // Check that the desired analysis type is supported
+  switch( eAnaType )
+  {
+    case eCMD_OP : eAnaType = eCMD_DC;
+    case eCMD_DC :
+    case eCMD_AC :
+    case eCMD_TR : break;
+    default      : return( FALSE );
+  }
+
+  m_eAnaType = eAnaType;
+
+  return( TRUE );
+}
+
 //*****************************************************************************
 // Parse the command string.
 //
@@ -52,25 +128,22 @@ bool  CmdNgSpicePR::bParse( void )
   // Clear the object attributes
   os1 = *this;
   bClear( );
-  *this = os1;
+  assign( os1 );
 
   // Tokenize the command string
   ostk1.SetString( *this );
-  if( ostk1.CountTokens( ) < 3 ) return( FALSE );
+  if( ostk1.CountTokens( ) < 3 ) return( bValidate( ) );
 
   // Check command type
-  os1 = ostk1.GetNextToken( ).Left( 6 ).Upper( );
-  if( os1 != wxT(".PRINT") )     return( FALSE );
-  m_osName = wxT("PRINT");
-
-  m_bIsOk = TRUE;
+  os1 = ostk1.GetNextToken( ).Left( 3 ).Upper( );
+  if( os1 != wxT(".PR") )        return( bValidate( ) );
 
   // Extract the analysis type
   os1 = ostk1.GetNextToken( );
-  if(      os1 == wxT("DC")   ) m_eAnaType = eANA_DC;
-  else if( os1 == wxT("AC")   ) m_eAnaType = eANA_AC;
-  else if( os1 == wxT("TRAN") ) m_eAnaType = eANA_TR;
-  else m_bIsOk = FALSE;
+  if(      os1 == wxT("DC")   ) m_eAnaType = eCMD_DC;
+  else if( os1 == wxT("AC")   ) m_eAnaType = eCMD_AC;
+  else if( os1 == wxT("TRAN") ) m_eAnaType = eCMD_TR;
+  else                           return( bValidate( ) );
 
   // Standardize the argument list format; there are 3 possible formats
   // eg. V(n), V(n,m) or 0-V(n), reformat the latter to : V(0,n).
@@ -78,7 +151,7 @@ bool  CmdNgSpicePR::bParse( void )
   while( ostk1.HasMoreTokens( ) )
   {
     os1 = ostk1.GetNextToken( );
-    if( os1.Length( ) < 4 ) { m_bIsOk = FALSE; continue; }
+    if( os1.Length( ) < 4 )      return( bValidate( ) );
 
     if( os1.StartsWith( wxT("0-") ) )
     {
@@ -102,15 +175,15 @@ bool  CmdNgSpicePR::bParse( void )
     // Extract the parameter specifiers
     switch( os1.GetChar( 0 ) )
     {
-      case wxT('V') : m_bParms[ ePAR_VLT ] = TRUE; break;
-      case wxT('I') : m_bParms[ ePAR_CUR ] = TRUE; break;
-      case wxT('P') : m_bParms[ ePAR_PWR ] = TRUE; break;
-      case wxT('R') : m_bParms[ ePAR_RES ] = TRUE; break;
-      default :       m_bIsOk = FALSE; break;
+      case wxT('V') : m_bParmtrs[ ePAR_VLT ] = TRUE; break;
+      case wxT('I') : m_bParmtrs[ ePAR_CUR ] = TRUE; break;
+      case wxT('P') : m_bParmtrs[ ePAR_PWR ] = TRUE; break;
+      case wxT('R') : m_bParmtrs[ ePAR_RES ] = TRUE; break;
+      default :                  return( bValidate( ) );
     }
 
     // Extract the complex parts if the analysis type is AC
-    if( m_eAnaType == eANA_AC )
+    if( m_eAnaType == eCMD_AC )
     {
       switch( os1.GetChar( 1 ) )
       {
@@ -125,26 +198,32 @@ bool  CmdNgSpicePR::bParse( void )
             m_bCpxPrts[ eCPX_MAGDB ] = TRUE;
             break;
           }
-        default: m_bIsOk = FALSE; break;
+        default :                return( bValidate( ) );
       }
     }
 
-    // Extract the node label/s, there are 2 possible formats eg. V(n) or
-    // V(n,m,...), the first denotes a node and the second a component.
+    // Extract the node and component label/s, there are 2 possible formats
+    // eg. V(n) or V(n,m,...), the first denotes a node and the second a
+    // component.
     i1 = os1.Index( wxT('(') );
     i2 = os1.Index( wxT(')') );
     if( i1!=-1 && i2!=-1 && i2>(i1+1) )
     {
       os1 = os1.Mid( (size_t) i1+1, (size_t) i2-i1-1 );
-      if( os1.Find( wxT(',') ) == -1 )
-        { if( m_osaNodes.Index( os1 ) == wxNOT_FOUND ) m_osaNodes.Add( os1 ); }
+
+      if( os1.Find( wxT(',') ) == wxNOT_FOUND )
+      { // This is a node, add it to the list if it's not already there
+        if( m_osaNodes.Index( os1 ) == wxNOT_FOUND ) m_osaNodes.Add( os1 );
+      }
       else
-        { if( m_osaCpnts.Index( os1 ) == wxNOT_FOUND ) m_osaCpnts.Add( os1 ); }
+      { // This is a component, add it to the list if it's not already there
+        if( m_osaCpnts.Index( os1 ) == wxNOT_FOUND ) m_osaCpnts.Add( os1 );
+      }
     }
-    else m_bIsOk = FALSE;
+    else                         return( bValidate( ) );
   }
 
-  return( m_bIsOk );
+  return( bValidate( ) );
 }
 
 //*****************************************************************************
@@ -163,25 +242,22 @@ bool  CmdNgSpicePR::bFormat( void )
   wxStringTokenizer  ostk1;
   int                i1, i2, i3;
 
-  m_bIsOk = FALSE;
-
   // Set the command name
   osCmd = wxT(".PRINT ");
-  if( m_osName.IsEmpty( ) ) m_osName = wxT("PRINT");
 
   // Append the analysis type
   switch( m_eAnaType )
   {
-    case eANA_DC : osCmd << wxT("DC");   break;
-    case eANA_AC : osCmd << wxT("AC");   break;
-    case eANA_TR : osCmd << wxT("TRAN"); break;
-    default :      return( FALSE );
+    case eCMD_DC : osCmd << wxT("DC");   break;
+    case eCMD_AC : osCmd << wxT("AC");   break;
+    case eCMD_TR : osCmd << wxT("TRAN"); break;
+    default      : break;
   }
 
   // Sequence through the various parameter types
   for( i1=ePAR_FST; i1<=ePAR_LST; i1++ )
   {
-    if( ! m_bParms[ i1 ] ) continue;
+    if( ! m_bParmtrs[ i1 ] ) continue;
 
     switch( (eParType) i1 )
     {
@@ -189,12 +265,12 @@ bool  CmdNgSpicePR::bFormat( void )
       case ePAR_CUR : osParm = wxT('I'); break;
       case ePAR_PWR : osParm = wxT('P'); break;
       case ePAR_RES : osParm = wxT('R'); break;
-      default :       return( FALSE );
+      default       : break;
     }
 
-    if( m_eAnaType != eANA_AC )
+    if( m_eAnaType != eCMD_AC )
     {
-      // Sequence throught all the components and nodes
+      // Sequence through all the components and nodes
       for( i3=0; i3<(int)m_osaCpnts.GetCount( ); i3++ )
         osCmd << wxT(' ') << osParm
               << wxT('(') << m_osaCpnts.Item( i3 ) << wxT(')');
@@ -216,7 +292,7 @@ bool  CmdNgSpicePR::bFormat( void )
           case eCPX_PHASE : osCpxPrt = wxT('P'); break;
           case eCPX_REAL  : osCpxPrt = wxT('R'); break;
           case eCPX_IMAG  : osCpxPrt = wxT('I'); break;
-          default :         return( FALSE );
+          default         : break;
         }
 
         // Sequence throught all the components and nodes
@@ -246,85 +322,144 @@ bool  CmdNgSpicePR::bFormat( void )
     osCmd << os1;
   }
 
-  *this = osCmd;
+  assign( osCmd );
 
-  m_bIsOk = TRUE;
-
-  return( TRUE );
+  return( bValidate( ) );
 }
 
 //*****************************************************************************
-// Clear the object attributes.
+// Get the total number of parameters to derive.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   The number of parameters to derive
 
-bool  CmdNgSpicePR::bClear( void )
+int  CmdNgSpicePR::iGetParaCnt( void )
+{
+  int  i1, i2, i3;
+
+  i1 = m_osaNodes.GetCount( ) + m_osaCpnts.GetCount( );
+
+  for( i2=0, i3=(int)ePAR_FST; i3<=(int)ePAR_LST; i3++ )
+    if( m_bParmtrs[ i3 ] )
+      i2++;
+
+  if( m_eAnaType == eCMD_AC )
+  {
+    for( i3=(int)eCPX_FST; i3<=(int)eCPX_LST-1; i3++ )
+      if( m_bCpxPrts[ i3 ] )
+        i2++;
+  }
+
+  return( i1 * ( i2 - 1 ) );
+}
+
+//*****************************************************************************
+// Copy the contents of another CmdNgSpicePR object.
+//
+// Argument List :
+//   roCmdPR - A reference to a CmdNgSpicePR object
+//
+// Return Values :
+//   A reference to this object
+
+CmdNgSpicePR & CmdNgSpicePR::operator = ( const CmdNgSpicePR & roCmdPR )
 {
   int  i1;
 
-  CmdBase::bClear( );
+  (CmdBase &) *this = (CmdBase &) roCmdPR;
 
-  m_eAnaType = eANA_NONE;
+  bSetAnaType( roCmdPR.m_eAnaType );
 
-  m_osaNodes.Empty( );
-  m_osaCpnts.Empty( );
+  m_osaNodes = roCmdPR.m_osaNodes;
+  m_osaCpnts = roCmdPR.m_osaCpnts;
 
-  for( i1=(int)ePAR_FST; i1<=(int)ePAR_LST; i1++ ) m_bParms  [ i1 ] = FALSE;
-  for( i1=(int)eCPX_FST; i1<=(int)eCPX_LST; i1++ ) m_bCpxPrts[ i1 ] = FALSE;
+  for( i1=(int)ePAR_FST; i1<=(int)ePAR_LST; i1++ )
+    m_bParmtrs[ i1 ] = roCmdPR.m_bParmtrs[ i1 ];
+  for( i1=(int)eCPX_FST; i1<=(int)eCPX_LST; i1++ )
+    m_bCpxPrts[ i1 ] = roCmdPR.m_bCpxPrts[ i1 ];
 
-  return( TRUE );
+  bFormat( );
+
+  return( *this );
+}
+
+//*****************************************************************************
+// Copy the contents of a CmdGnuCapPR object.
+//
+// Argument List :
+//   roCmdPR - A reference to a CmdGnuCapPR object
+//
+// Return Values :
+//   A reference to this object
+
+CmdNgSpicePR & CmdNgSpicePR::operator = ( const CmdGnuCapPR & roCmdPR )
+{
+  int  i1;
+
+  (CmdBase &) *this = (CmdBase &) roCmdPR;
+
+  bSetAnaType( roCmdPR.m_eAnaType );
+
+  m_osaNodes = roCmdPR.m_osaNodes;
+  m_osaCpnts = roCmdPR.m_osaCpnts;
+
+  for( i1=(int)ePAR_FST; i1<=(int)ePAR_LST; i1++ )
+    m_bParmtrs[ i1 ] = roCmdPR.m_bParmtrs[ i1 ];
+  for( i1=(int)eCPX_FST; i1<=(int)eCPX_LST; i1++ )
+    m_bCpxPrts[ i1 ] = roCmdPR.m_bCpxPrts[ i1 ];
+
+  bFormat( );
+
+  return( *this );
 }
 
 //*****************************************************************************
 // Print the object attributes.
 //
 // Argument List :
-//   psPrefix - A prefix to every line displayed (usually just spaces)
+//   rosPrefix - A prefix to every line displayed (usually just spaces)
 
-void  CmdNgSpicePR::Print( const char * psPrefix )
+void  CmdNgSpicePR::Print( const wxString & rosPrefix )
 {
   int     i1;
   size_t  sz1;
 
-  cout << psPrefix << "Command string  : " << this->mb_str( ) << '\n';
-  cout << psPrefix << "m_bIsOk         : " << ( m_bIsOk ? "TRUE" : "FALSE" ) << '\n';
-  cout << psPrefix << "m_osName        : " << m_osName.mb_str( ) << '\n';
+  CmdBase::Print( rosPrefix + wxT("CmdBase::") );
 
-  cout << psPrefix << "m_eAnaType      : ";
+  cout << rosPrefix.mb_str( ) << "m_eAnaType      : ";
   switch( m_eAnaType )
   {
-    case eANA_OP   : cout << "eANA_OP";   break;  // Operating point analysis
-    case eANA_DC   : cout << "eANA_DC";   break;  // DC analysis
-    case eANA_AC   : cout << "eANA_AC";   break;  // AC analysis
-    case eANA_TR   : cout << "eANA_TR";   break;  // Transient analysis
-    case eANA_FO   : cout << "eANA_FO";   break;  // Fourier analysis
-    case eANA_DI   : cout << "eANA_DI";   break;  // Distortion analysis
-    case eANA_NO   : cout << "eANA_NO";   break;  // Noise analysis
-    case eANA_PZ   : cout << "eANA_PZ";   break;  // Pole-zero analysis
-    case eANA_SE   : cout << "eANA_SE";   break;  // Sensitivity analysis
-    case eANA_TF   : cout << "eANA_TF";   break;  // Transfer function analysis
-    case eANA_NONE : cout << "eANA_NONE"; break;  // Analysis type not set
+    case eCMD_OP   : cout << "eCMD_OP";   break;  // Operating point analysis
+    case eCMD_DC   : cout << "eCMD_DC";   break;  // DC analysis
+    case eCMD_AC   : cout << "eCMD_AC";   break;  // AC analysis
+    case eCMD_TR   : cout << "eCMD_TR";   break;  // Transient analysis
+    case eCMD_FO   : cout << "eCMD_FO";   break;  // Fourier analysis
+    case eCMD_DI   : cout << "eCMD_DI";   break;  // Distortion analysis
+    case eCMD_NO   : cout << "eCMD_NO";   break;  // Noise analysis
+    case eCMD_PZ   : cout << "eCMD_PZ";   break;  // Pole-zero analysis
+    case eCMD_SE   : cout << "eCMD_SE";   break;  // Sensitivity analysis
+    case eCMD_TF   : cout << "eCMD_TF";   break;  // Transfer function analysis
+    case eCMD_NONE : cout << "eCMD_NONE"; break;  // Analysis type not set
+    default        : cout << "Invalid";   break;
   }
   cout << '\n';
 
-  cout << psPrefix << "m_osaCpnts[ n ] :";
+  cout << rosPrefix.mb_str( ) << "m_osaCpnts[ n ] :";
   for( sz1=0; sz1<m_osaCpnts.GetCount( ); sz1++ )
     cout << ' ' << m_osaCpnts[ sz1 ].mb_str( );
   cout << '\n';
 
-  cout << psPrefix << "m_osaNodes[ n ] :";
+  cout << rosPrefix.mb_str( ) << "m_osaNodes[ n ] :";
   for( sz1=0; sz1<m_osaNodes.GetCount( ); sz1++ )
     cout << ' ' << m_osaNodes[ sz1 ].mb_str( );
   cout << '\n';
 
-  cout << psPrefix << "m_bParms[ n ]   :";
+  cout << rosPrefix.mb_str( ) << "m_bParms  [ n ] :";
   for( i1=(int)ePAR_FST; i1<=(int)ePAR_LST; i1++ )
-    cout << ( m_bParms[ i1 ]   ? " TRUE " : " FALSE" );
+    cout << ( m_bParmtrs[ i1 ] ? " TRUE " : " FALSE" );
   cout << '\n';
 
-  cout << psPrefix << "m_bCpxPrts[ n ] :";
+  cout << rosPrefix.mb_str( ) << "m_bCpxPrts[ n ] :";
   for( i1=(int)eCPX_FST; i1<=(int)eCPX_LST; i1++ )
     cout << ( m_bCpxPrts[ i1 ] ? " TRUE " : " FALSE" );
   cout << '\n';
@@ -368,7 +503,7 @@ int  main( int argc, char * argv[ ] )
 
   // Display the utility banner
   cout << "\n  Class CmdNgSpicePR Test Utility"
-       << "\n     Version 1.00 (20/12/2007)\n";
+       << "\n     Version 1.01 (04/06/2009)\n";
 
   // Create a NG-SPICE PRINT command object
   CmdNgSpicePR  oCmd_PR;
@@ -378,7 +513,7 @@ int  main( int argc, char * argv[ ] )
 
   // Set things up for a formatter test
   oCmd_PR.bClear( );
-  oCmd_PR.m_eAnaType = eANA_AC;
+  oCmd_PR.m_eAnaType = eCMD_AC;
   oCmd_PR.m_osaCpnts.Add( wxT("6,0") );
   oCmd_PR.m_osaCpnts.Add( wxT("0,5") );
   oCmd_PR.m_osaCpnts.Add( wxT("1,7") );
@@ -393,7 +528,7 @@ int  main( int argc, char * argv[ ] )
 
   // Set things up for a parser test
   oCmd_PR.bClear( );
-  oCmd_PR = osCmd;
+  oCmd_PR.bSetString( osCmd );
   cout << "\nRun Parser      : " << ( oCmd_PR.bParse( ) ? "OK" : "FAULT" );
   oCmd_PR.bFormat( );
   cout << "\nTest Cmd Format : " << ( oCmd_PR == osCmd  ? "OK" : "FAULT" );
