@@ -1,12 +1,12 @@
 //*****************************************************************************
 //                              CmdNgSpicePR.hpp                              *
 //                             ------------------                             *
-//  Description : This class contains values associated with the NG-Spice     *
-//                AC command. It inherits from the class CmdBase.             *
-//  Started     : 16/10/2007                                                  *
-//  Last Update : 18/01/2008                                                  *
-//  Copyright   : (C) 2007 by M.S.Waters                                      *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Description : This class contains values associated with the NG-Spice      *
+//               PRINT command. It inherits from the class CmdBase.           *
+// Started     : 16/10/2007                                                   *
+// Last Update : 16/09/2009                                                   *
+// Copyright   : (C) 2007 by M.S.Waters                                       *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -35,9 +35,10 @@ using  namespace  std;
 
 // Application Includes
 
-#include "TypeDefs.hpp"
 #include "base/CmdBase.hpp"
-#include "utility/ConvertType.hpp"
+#include "gnucap/commands/CmdGnuCapPR.hpp"
+
+struct CmdGnuCapPR;
 
 // Local Macro and Constant Declarations
 
@@ -46,26 +47,34 @@ using  namespace  std;
 
 struct CmdNgSpicePR : public CmdBase
 {
+  private :
+
+    virtual  bool  bValidate( void );
+
   public :
 
-    eAnaType       m_eAnaType;
+    eCmdType       m_eAnaType;
     wxArrayString  m_osaNodes;
     wxArrayString  m_osaCpnts;
-    bool           m_bParms  [ ePAR_LST+1 ];
+    bool           m_bParmtrs[ ePAR_LST+1 ];
     bool           m_bCpxPrts[ eCPX_LST+1 ];
 
-              CmdNgSpicePR( void );
-    virtual  ~CmdNgSpicePR( );
+             CmdNgSpicePR( void );
+    virtual ~CmdNgSpicePR( );
 
-    bool  bClear( void );
+    virtual  bool  bClear( void );
+
+             bool  bSetAnaType( eCmdType eAnaType );
 
     virtual  bool  bParse ( void );
     virtual  bool  bFormat( void );
 
-    wxString & operator = ( const wxString & ros )
-                { *((wxString *) this) = ros; return( *((wxString *) this) ); }
+             int   iGetParaCnt( void );
 
-    void  Print( const char * psPrefix="" );
+    CmdNgSpicePR & operator = ( const CmdNgSpicePR & roCmdPR );
+    CmdNgSpicePR & operator = ( const CmdGnuCapPR  & roCmdPR );
+
+    void  Print( const wxString & rosPrefix=wxT("  ") );
 };
 
 //*****************************************************************************
