@@ -1,10 +1,10 @@
 //*****************************************************************************
 //                              CmdNgSpiceTR.cpp                              *
 //                             ------------------                             *
-//  Started     : 15/10/2007                                                  *
-//  Last Update : 21/02/2008                                                  *
-//  Copyright   : (C) 2007 by M.S.Waters                                      *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Started     : 15/10/2007                                                   *
+// Last Update : 19/08/2009                                                   *
+// Copyright   : (C) 2007 by M.S.Waters                                       *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -33,6 +33,66 @@ CmdNgSpiceTR::~CmdNgSpiceTR( )
 {
 }
 
+//*****************************************************************************
+// Check that the object attributes are valid.
+//
+// Return Values :
+//   TRUE  - Success
+//   FALSE - Failure
+
+bool  CmdNgSpiceTR::bValidate( void )
+{
+  double  df1, df2, df3;
+
+  CmdBase::bValidate( );
+
+  // Check the sweep start and stop values
+  if( ! ConvertType::bStrToDFlt( m_osStart, &df1 ) )
+    SetErrMsg( wxT("Invalid sweep start value.") );
+  if( ! ConvertType::bStrToDFlt( m_osStop,  &df2 ) )
+    SetErrMsg( wxT("Invalid sweep stop value.") );
+  if( df2 < df1 )
+    SetErrMsg( wxT("Start value greater than stop value.") );
+
+  // Check the sweep step value and initial conditions
+  if( ! ConvertType::bStrToDFlt( m_osStep, &df3 ) )
+    SetErrMsg( wxT("Invalid sweep step value.") );
+  if( df3 <= 0.0 )
+    SetErrMsg( wxT("Step value less than or equal to zero.") );
+  switch( m_eInitC )
+  {
+    case eINITC_WARM :
+    case eINITC_UICS :
+    case eINITC_COLD : break;
+    default          : SetErrMsg( wxT("Invalid initial conditions value.") );
+  }
+
+  return( bIsValid( ) );
+}
+
+//*****************************************************************************
+// Clear the object attributes.
+//
+// Return Values :
+//   TRUE  - Success
+//   FALSE - Failure
+
+bool  CmdNgSpiceTR::bClear( void )
+{
+  CmdBase::bClear( );
+
+  m_eSimEng  = eSIMR_NGSPICE;
+  m_eCmdType = eCMD_TR;
+
+  m_osStart = wxT("0.0m");
+  m_osStop  = wxT("100.0m");
+  m_osStep  = wxT("10.0m");
+
+  m_eInitC = eINITC_WARM;
+
+  return( TRUE );
+}
+
 //*****************************************************************************
 // Parse the command string.
 //
@@ -55,37 +115,34 @@ bool  CmdNgSpiceTR::bParse( void )
   // Clear the object attributes
   os1 = *this;
   bClear( );
-  *this = os1;
+  assign( os1 );
 
   // Tokenize the command string
   ostk1.SetString( *this );
   i1 = ostk1.CountTokens( );
-  if( i1<3 || i1>6 )        return( FALSE );
+  if( i1<3 || i1>6 )      return( bValidate( ) );
 
   // Check command type
-  os1 = ostk1.GetNextToken( ).Left( 5 ).Upper( );
-  if( os1 != wxT(".TRAN") ) return( FALSE );
-  m_osName = wxT("TRAN");
-
-  m_bIsOk = TRUE;
+  os1 = ostk1.GetNextToken( ).Left( 3 ).Upper( );
+  if( os1 != wxT(".TR") ) return( bValidate( ) );
 
   // Extract the step increment (must be present)
   os1 = ostk1.GetNextToken( );
-  if( ConvertType::bStrToFlt( os1, &df1 ) )   m_fStep  = (float) df1;
-  else                      m_bIsOk = FALSE;
+  if( ConvertType::bStrToDFlt( os1, &df1 ) )   m_osStep  = os1;
+  else                    return( bValidate( ) );
 
   // Extract the stop value (must be present)
   os1 = ostk1.GetNextToken( );
-  if( ConvertType::bStrToFlt( os1, &df1 ) )   m_fStop  = (float) df1;
-  else                      m_bIsOk = FALSE;
+  if( ConvertType::bStrToDFlt( os1, &df1 ) )   m_osStop  = os1;
+  else                    return( bValidate( ) );
 
   // Extract the start value (may be omitted)
-  m_fStart = 0.0;
+  m_osStart = wxT("0.0");
   if( ostk1.HasMoreTokens( ) )
   {
     os1 = ostk1.GetNextToken( );
-    if( ConvertType::bStrToFlt( os1, &df1 ) ) m_fStart = (float) df1;
-    else                    m_bIsOk = FALSE;
+    if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osStart = os1;
+    else                  return( bValidate( ) );
   }
 
   // Extract the initial conditions specifier
@@ -100,7 +157,7 @@ bool  CmdNgSpiceTR::bParse( void )
     }
   }
 
-  return( m_bIsOk );
+  return( bValidate( ) );
 }
 
 //*****************************************************************************
@@ -112,48 +169,73 @@ bool  CmdNgSpiceTR::bParse( void )
 
 bool  CmdNgSpiceTR::bFormat( void )
 {
-  wxString  osCmd, os1;
-
-  m_bIsOk = FALSE;
+  wxString  osCmd;
 
+  // Set the command name
   osCmd = wxT(".TRAN");
 
-  if( ! ConvertType::bFltToStrEng( (double) m_fStep,  os1 ) ) return( FALSE );
-  osCmd << wxT(' ') << os1;
+  // Set sweep parameters
+  osCmd << wxT(' ') << m_osStep;
+  osCmd << wxT(' ') << m_osStop;
+  osCmd << wxT(' ') << m_osStart;
 
-  if( ! ConvertType::bFltToStrEng( (double) m_fStop,  os1 ) ) return( FALSE );
-  osCmd << wxT(' ') << os1;
+  // Set initial conditions
+  if( m_eInitC != eINITC_WARM ) osCmd << wxT(" UIC");
 
-  if( ! ConvertType::bFltToStrEng( (double) m_fStart, os1 ) ) return( FALSE );
-  osCmd << wxT(' ') << os1;
+  assign( osCmd );
 
-  if( m_eInitC == eINITC_UICS ) osCmd << wxT(" UIC");
-
-  *this = osCmd;
-
-  m_bIsOk = TRUE;
-
-  return( m_bIsOk );
+  return( bValidate( ) );
 }
 
 //*****************************************************************************
-// Clear the object attributes.
+// Copy the contents of a CmdGnuCapAC object.
+//
+// Argument List :
+//   roCmdTR - A reference to a CmdGnuCapTR object
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   A reference to this object
 
-bool  CmdNgSpiceTR::bClear( void )
+CmdNgSpiceTR & CmdNgSpiceTR::operator = ( const CmdGnuCapTR & roCmdTR )
 {
-  CmdBase::bClear( );
+  (CmdBase &) *this = (CmdBase &) roCmdTR;
 
-  m_fStart = -FLT_MAX;
-  m_fStop  = -FLT_MAX;
-  m_fStep  = -FLT_MAX;
+  m_osStart = roCmdTR.m_osStart;
+  m_osStop  = roCmdTR.m_osStop;
+  m_osStep  = roCmdTR.m_osStep;
+  m_eInitC  = roCmdTR.m_eInitC;
 
-  m_eInitC = eINITC_NONE;
+  bFormat( );
 
-  return( TRUE );
+  return( *this );
+}
+
+//*****************************************************************************
+// Print the object attributes.
+//
+// Argument List :
+//   rosPrefix - A prefix to every line displayed (usually just spaces)
+
+void  CmdNgSpiceTR::Print( const wxString & rosPrefix )
+{
+  CmdBase::Print( rosPrefix + wxT("CmdBase::") );
+
+  cout << rosPrefix.mb_str( ) << "m_osStart : "
+       << m_osStart.mb_str( ) << '\n';
+  cout << rosPrefix.mb_str( ) << "m_osStop  : "
+       << m_osStop .mb_str( ) << '\n';
+  cout << rosPrefix.mb_str( ) << "m_osStep  : "
+       << m_osStep .mb_str( ) << '\n';
+
+  cout << rosPrefix.mb_str( ) << "m_eInitC  : ";
+  switch( m_eInitC )
+  {
+    case eINITC_WARM : cout << "eINITC_COLD\n"; break;
+    case eINITC_UICS : cout << "eINITC_UICS\n"; break;
+    case eINITC_COLD : cout << "eINITC_COLD\n"; break;
+    case eINITC_NONE : cout << "eINITC_NONE\n"; break;
+    default :          cout << "Invalid\n";     break;
+  }
 }
 
 //*****************************************************************************
@@ -194,7 +276,7 @@ int  main( int argc, char * argv[ ] )
 
   // Display the utility banner
   cout << "\n  Class CmdNgSpiceTR Test Utility"
-       << "\n     Version 1.00 (01/02/2008)\n";
+       << "\n     Version 1.01 (04/06/2009)\n";
 
   // Create a NG-SPICE TRANSIENT command object
   CmdNgSpiceTR  oCmd_TR;
@@ -204,9 +286,9 @@ int  main( int argc, char * argv[ ] )
 
   // Set things up for a formatter test
   oCmd_TR.bClear( );
-  oCmd_TR.m_fStart = 0.0;
-  oCmd_TR.m_fStop  = 100.0E-3;
-  oCmd_TR.m_fStep  = 10.0E-3;
+  oCmd_TR.m_osStart = wxT("0.00");
+  oCmd_TR.m_osStop  = wxT("100.00m");
+  oCmd_TR.m_osStep  = wxT("10.00m");
   oCmd_TR.m_eInitC = eINITC_UICS;
   cout << "\nRun Formatter    : " << ( oCmd_TR.bFormat( ) ? "OK" : "FAULT" );
   cout << "\nTest Cmd Format  : " << ( oCmd_TR == osCmd   ? "OK" : "FAULT" );
@@ -215,7 +297,7 @@ int  main( int argc, char * argv[ ] )
 
   // Set things up for a parser test
   oCmd_TR.bClear( );
-  oCmd_TR = osCmd;
+  oCmd_TR.bSetString( osCmd );
   cout << "\nRun Parser       : " << ( oCmd_TR.bParse( ) ? "OK" : "FAULT" );
   oCmd_TR.bFormat( );
   cout << "\nTest Cmd Format  : " << ( oCmd_TR == osCmd  ? "OK" : "FAULT" );
