@@ -1,12 +1,12 @@
 //*****************************************************************************
 //                              CmdNgSpiceTR.hpp                              *
 //                             ------------------                             *
-//  Description : This class contains values associated with the NG-Spice     *
-//                TRANSIENT command. It inherits from the class CmdBase.      *
-//  Started     : 15/10/2007                                                  *
-//  Last Update : 15/01/2008                                                  *
-//  Copyright   : (C) 2007 by M.S.Waters                                      *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Description : This class contains values associated with the NG-Spice      *
+//               TRANSIENT command. It inherits from the class CmdBase.       *
+// Started     : 15/10/2007                                                   *
+// Last Update : 13/05/2009                                                   *
+// Copyright   : (C) 2007 by M.S.Waters                                       *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -33,33 +33,40 @@
 
 // Application Includes
 
-#include "TypeDefs.hpp"
 #include "base/CmdBase.hpp"
+#include "gnucap/commands/CmdGnuCapTR.hpp"
 #include "utility/ConvertType.hpp"
 
+struct CmdGnuCapTR;
+
 // Local Macro and Constant Declarations
 
 //*****************************************************************************
 
 struct CmdNgSpiceTR : public CmdBase
 {
+  private :
+
+    virtual  bool  bValidate( void );
+
   public :
 
-    float       m_fStart;    // The sweep start value
-    float       m_fStop;     // The sweep stop  value
-    float       m_fStep;     // The sweep step  value
-    eInitCType  m_eInitC;    // The initial conditions
+    wxString    m_osStart;  // The sweep start value
+    wxString    m_osStop;   // The sweep stop  value
+    wxString    m_osStep;   // The sweep step  value
+    eInitCType  m_eInitC;   // The initial conditions
 
-              CmdNgSpiceTR( void );
-    virtual  ~CmdNgSpiceTR( );
+             CmdNgSpiceTR( void );
+    virtual ~CmdNgSpiceTR( );
 
-    bool  bClear( void );
+    virtual  bool  bClear   ( void );
 
     virtual  bool  bParse ( void );
     virtual  bool  bFormat( void );
 
-    wxString & operator = ( const wxString & ros )
-                { *((wxString *) this) = ros; return( *((wxString *) this) ); }
+    CmdNgSpiceTR & operator = ( const CmdGnuCapTR & roCmdTR );
+
+    void  Print( const wxString & rosPrefix=wxT("  ") );
 };
 
 //*****************************************************************************
