@@ -1,11 +1,11 @@
 //*****************************************************************************
-//                               PnlNgSpiceDC.hpp                             *
-//                              ------------------                            *
+//                             PnlNgSpiceDC.hpp                               *
+//                            ------------------                              *
 // Description : This class derives from the PnlAnaBase base class and        *
 //               provides a GUI for a user to configure a DC Analysis for     *
 //               NG-Spice electronic circuit simulator.                       *
 // Started     : 08/05/2004                                                   *
-// Last Update : 05/10/2007                                                   *
+// Last Update : 21/08/2009                                                   *
 // Copyright   : (C) 2004 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -31,6 +31,7 @@
 // Application Includes
 
 #include "base/PnlAnaBase.hpp"
+#include "netlist/SimnNgSpice.hpp"
 
 // Local Constant Declarations
 
@@ -39,44 +40,43 @@
 
 class PnlNgSpiceDC : public PnlAnaBase
 {
-  public:
+  public :
 
     // Enumerated type for specifying the sweep type
     enum  eSweepType
     {
-      eSWP_SIGSRC,
+      eSWP_CPNT = 0,
       eSWP_TEMP,
 
-      eSWP_FST = eSWP_SIGSRC,
+      eSWP_FST = eSWP_CPNT,
       eSWP_LST = eSWP_TEMP
     };
 
-  private:
+  private :
 
     // Sweep type
     wxRadioBox    m_oRbxSwpType;
 
     // Sweep source
-    wxStaticText  m_oLblSigSrcCpnt;
+    wxStaticText  m_oLblSrcCpnt;
 
     void  Create( void );
     void  InitSwpType( void );
     void  InitSwpUnits( void );
-    bool  bSetSwpType( eSweepType eSwpType );
 
-  public:
+  public :
 
     PnlNgSpiceDC( wxWindow * poWin );
    ~PnlNgSpiceDC( );
 
     bool  bClear( void );
 
-    bool  bLoad( Simulation & roSim );
-    bool  bSave( Simulation & roSim );
+    bool  bLoad( SimnNgSpice & roSimn );
+    bool  bSave( SimnNgSpice & roSimn );
 
     // Event handlers
-    void  OnSwpType    ( wxCommandEvent & roEvtCmd );
-    void  OnSigSrcCpnt ( wxCommandEvent & roEvtCmd );
+    void  OnSwpType( wxCommandEvent & roEvtCmd );
+    void  OnSrcName( wxCommandEvent & roEvtCmd );
 
     // In order to be able to react to a menu command, it must be given a
     // unique identifier such as a const or an enum.
