@@ -63,7 +63,7 @@ class PrcGWave : public PrcBase
 
     const wxFileName & roGetResults( void ) { return( m_ofnResults ); }
 
-    bool  bExec( void );
+    virtual  bool  bExec( void );
 };
 
 //*****************************************************************************
