@@ -4,7 +4,7 @@
 //  Description : This class provides the interface to the NG-Spice circuit   *
 //                simulator.                                                  *
 //  Started     : 07/05/2004                                                  *
-//  Last Update : 10/01/2008                                                  *
+//  Last Update : 04/09/2009                                                  *
 //  Copyright   : (C) 2004 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -32,12 +32,12 @@
 
 #include "TypeDefs.hpp"
 #include "base/PrcSimrBase.hpp"
-#include "netlist/Component.hpp"
-#include "utility/ConvertType.hpp"
+#include "netlist/SimnGnuCap.hpp"
 #include "ngspice/commands/CmdNgSpiceDC.hpp"
 #include "ngspice/commands/CmdNgSpiceAC.hpp"
 #include "ngspice/commands/CmdNgSpiceTR.hpp"
 #include "ngspice/commands/CmdNgSpicePR.hpp"
+#include "utility/ConvertType.hpp"
 
 // Local Constant Declarations
 
@@ -47,50 +47,36 @@
 
 class PrcNgSpice : public PrcSimrBase
 {
-  private:
+  private :
 
-    // Storage for the field list (used to replace NG-Spice field identifiers)
-    wxString  m_osFieldLst;
-
-    // Functions to parse simulator commands
-    bool  bParseCmdOP( wxString & rosCmd, Simulation & roSim );
-    bool  bParseCmdIC( wxString & rosCmd, Simulation & roSim );
-    bool  bParseCmdDC( wxString & rosCmd, Simulation & roSim );
-    bool  bParseCmdAC( wxString & rosCmd, Simulation & roSim );
-    bool  bParseCmdTR( wxString & rosCmd, Simulation & roSim );
-    bool  bParseCmdPR( wxString & rosCmd, Simulation & roSim );
+    // Storage for the result file column labels
+    wxString  m_osColLbls;
 
     // Function to match a component to a set of node labels
-    bool  bMatchCpnt( Simulation & roSim, wxString & rosToNodes );
+    bool  bMatchCpnt( SimnNgSpice & roSimn, wxString & rosToNodes );
 
     // Functions to create the simulator commands
-    void  MakeCmdsDC( Simulation & roSim );
-    void  MakeCmdsAC( Simulation & roSim );
-    void  MakeCmdsTR( Simulation & roSim );
-    bool  bMakeCmds ( Simulation & roSim );
-    void  MakeFieldLst( CmdNgSpicePR & rtCmd_PR, Simulation & roSim );
-    void  Convert2Nodes( wxArrayString & roasCpnts, Simulation & roSim );
+    void  Convert2Nodes( wxArrayString & rosaCpnts, SimnNgSpice & roSimn );
 
     // Create the WIDTH command
     wxString & rosMakeCmdWIDTH( wxString & rosCmdPR );
 
     // Format the results file
-    bool  bFmtResults  ( void );
     bool  bFmtGeneric  ( void );
     bool  bFmtColumnHdr( void );
     bool  bFmtDataLines( void );
     bool  bFmtPhaseData( void ); // ??? (02/02/2006) Not yet implemented
 
-  public:
+  public :
 
     PrcNgSpice( void );
    ~PrcNgSpice( );
 
-    // Parse the simulation commands
-    virtual  bool  bParseSim( Simulation & roSim );
+    // Create the process argument list
+    virtual  bool  bMakeArgLst( SimnBase & roSimn );
 
-    // Make the simulation commands
-    virtual  bool  bMakeSim( Simulation & roSim );
+    // Format the results file
+    virtual  bool  bFmtResults( void );
 };
 
 //*****************************************************************************
