@@ -2,7 +2,7 @@
 //                                 PnlValue.cpp                               *
 //                                --------------                              *
 //  Started     : 14/09/2004                                                  *
-//  Last Update : 15/02/2008                                                  *
+//  Last Update : 21/01/2009                                                  *
 //  Copyright   : (C) 2004 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -57,9 +57,9 @@ PnlValue::~PnlValue( )
 
 bool  PnlValue::bTempToDegC( float * pfValue )
 {
-  if( ! bIsCreated( ) )                                       return( FALSE );
-  if( ! m_bUseUnits || ! m_oChoUnits.IsShown( ) )             return( FALSE );
-  if( m_oChoUnits.eGetUnitsType( ) != ChoUnits::eUNITS_TEMP ) return( FALSE );
+  if( ! bIsCreated( ) )                             return( FALSE );
+  if( ! m_bUseUnits || ! m_oChoUnits.IsShown( ) )   return( FALSE );
+  if( m_oChoUnits.eGetUnitsType( ) != eUNITS_TEMP ) return( FALSE );
 
   switch( m_oChoUnits.GetSelection( ) )
   {
@@ -86,9 +86,9 @@ bool  PnlValue::bTempToDegC( float * pfValue )
 
 bool  PnlValue::bPhaseToDeg( float * pfValue )
 {
-  if( ! bIsCreated( ) )                                        return( FALSE );
-  if( ! m_bUseUnits || ! m_oChoUnits.IsShown( ) )              return( FALSE );
-  if( m_oChoUnits.eGetUnitsType( ) != ChoUnits::eUNITS_PHASE ) return( FALSE );
+  if( ! bIsCreated( ) )                              return( FALSE );
+  if( ! m_bUseUnits || ! m_oChoUnits.IsShown( ) )    return( FALSE );
+  if( m_oChoUnits.eGetUnitsType( ) != eUNITS_PHASE ) return( FALSE );
 
   switch( m_oChoUnits.GetSelection( ) )
   {
@@ -196,6 +196,11 @@ bool  PnlValue::bCreate( wxWindow * poWin, wxWindowID oWinID, int iWidth,
   // Layout the display objects
   DoLayout( );
 
+
+// (15/10/2008) I suspect that the following just fixes a bug in wxWidgets, the
+// back-ground of the parent window isn't inherited by it's children
+this->SetBackgroundColour( poWin->GetBackgroundColour( ) ); // ???
+
   return( bRtn );
 }
 
@@ -428,10 +433,10 @@ bool  PnlValue::bSetValue( const wxString & rosValue, bool bNoUnits )
 {
   double  df1;
 
-  if( ! bIsCreated( ) )                            return( FALSE );
+  if( ! bIsCreated( ) )                             return( FALSE );
 
-  if( ! ConvertType::bStrToFlt( rosValue, &df1 ) ) return( FALSE );
-  if( ! bSetValue( df1, bNoUnits ) )               return( FALSE );
+  if( ! ConvertType::bStrToDFlt( rosValue, &df1 ) ) return( FALSE );
+  if( ! bSetValue( df1, bNoUnits ) )                return( FALSE );
 
   return( TRUE );
 }
@@ -446,7 +451,7 @@ bool  PnlValue::bSetValue( const wxString & rosValue, bool bNoUnits )
 //   Success - TRUE
 //   Failure - FALSE
 
-bool  PnlValue::bSetUnitsType( ChoUnits::eUnitsType eUType )
+bool  PnlValue::bSetUnitsType( eUnitsType  eUType )
 {
   bool  bRtn;
 
@@ -457,34 +462,34 @@ bool  PnlValue::bSetUnitsType( ChoUnits::eUnitsType eUType )
   // Automatically set the spin control parameters
   switch( eUType )
   {
-    case ChoUnits::eUNITS_CAP   :  // Capacitance
+    case eUNITS_CAP   :  // Capacitance
       bRtn = m_oSpnValue.bSetParms( 100.0,     0.0, 1000.0, 1.0, 100.0 );
       break;
-    case ChoUnits::eUNITS_IND   :  // Inductance
+    case eUNITS_IND   :  // Inductance
       bRtn = m_oSpnValue.bSetParms( 100.0,     0.0, 1000.0, 1.0, 100.0 );
       break;
-    case ChoUnits::eUNITS_RES   :  // Resistance
+    case eUNITS_RES   :  // Resistance
       bRtn = m_oSpnValue.bSetParms( 100.0,     0.0, 1000.0, 1.0, 100.0 );
       break;
-    case ChoUnits::eUNITS_VOLT  :  // Voltage
+    case eUNITS_VOLT  :  // Voltage
       bRtn = m_oSpnValue.bSetParms( 100.0, -1000.0, 1000.0, 1.0, 100.0 );
       break;
-    case ChoUnits::eUNITS_CURR  :  // Current
+    case eUNITS_CURR  :  // Current
       bRtn = m_oSpnValue.bSetParms( 100.0, -1000.0, 1000.0, 1.0, 100.0 );
       break;
-    case ChoUnits::eUNITS_TIME  :  // Time
+    case eUNITS_TIME  :  // Time
       bRtn = m_oSpnValue.bSetParms( 100.0,     0.0, 1000.0, 1.0, 100.0 );
       break;
-    case ChoUnits::eUNITS_FREQ  :  // Frequency
+    case eUNITS_FREQ  :  // Frequency
       bRtn = m_oSpnValue.bSetParms( 100.0,     0.0, 1000.0, 1.0, 100.0 );
       break;
-    case ChoUnits::eUNITS_PHASE :  // Phase
+    case eUNITS_PHASE :  // Phase
       bRtn = m_oSpnValue.bSetParms(   0.0,     0.0,  360.0, 5.0 );
       break;
-    case ChoUnits::eUNITS_TEMP  :  // Temperature
+    case eUNITS_TEMP  :  // Temperature
       bRtn = m_oSpnValue.bSetParms(  27.0,  -100.0,  200.0, 1.0,   5.0 );
       break;
-    case ChoUnits::eUNITS_SCLR  :  // Scalar
+    case eUNITS_SCLR  :  // Scalar
       bRtn = m_oSpnValue.bSetParms(   1.0, -1000.0, 1000.0, 1.0, 100.0 );
       break;
     default:                       // Default
@@ -689,8 +694,8 @@ void  PnlValue::OnSpnScroll( wxSpinEvent & roEvtSpn )
           int    i1;
 
   if( ! m_bUseUnits || ! m_oChoUnits.IsShown( ) )              return;
-  if( m_oChoUnits.eGetUnitsType( ) == ChoUnits::eUNITS_TEMP  ) return;
-  if( m_oChoUnits.eGetUnitsType( ) == ChoUnits::eUNITS_PHASE ) return;
+  if( m_oChoUnits.eGetUnitsType( ) == eUNITS_TEMP  )           return;
+  if( m_oChoUnits.eGetUnitsType( ) == eUNITS_PHASE )           return;
 
   f1 = m_oSpnValue.fGetValue( );
   i1 = m_oChoUnits.iGetUnits( );
@@ -752,7 +757,7 @@ void  PnlValue::OnSpnScroll( wxSpinEvent & roEvtSpn )
 
 void  PnlValue::OnChoUnits( wxCommandEvent & roEvtCmd )
 {
-  if(      m_oChoUnits.eGetUnitsType( ) == ChoUnits::eUNITS_TEMP )
+  if(      m_oChoUnits.eGetUnitsType( ) == eUNITS_TEMP )
   {
          if( m_oChoUnits.rosGetUnits( ).IsSameAs( wxT("Deg C") ) )
       bSetParms( 27.0, -100.0, 200.0, 1.0 );
@@ -761,7 +766,7 @@ void  PnlValue::OnChoUnits( wxCommandEvent & roEvtCmd )
     else if( m_oChoUnits.rosGetUnits( ).IsSameAs( wxT("Deg K") ) )
       bSetParms( 300.0, 200.0, 500.0, 1.0 );
   }
-  else if( m_oChoUnits.eGetUnitsType( ) == ChoUnits::eUNITS_PHASE )
+  else if( m_oChoUnits.eGetUnitsType( ) == eUNITS_PHASE )
   {
          if( m_oChoUnits.rosGetUnits( ).IsSameAs( wxT("Degree") ) )
       bSetParms( 0.0, 0.0, 360.0, 1.0 );
