@@ -6,7 +6,7 @@
 //                floating point variables and can optionally allow the       *
 //                setting and processing of units.                            *
 //  Started     : 14/09/2004                                                  *
-//  Last Update : 06/09/2007                                                  *
+//  Last Update : 20/08/2009                                                  *
 //  Copyright   : (C) 2004 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -49,23 +49,23 @@ typedef  wxStaticText  wxLabel;
 
 class PnlValue : public wxPanel
 {
-  private:
+  private :
 
     // Flag indicating if units should accommodated
     bool      m_bUseUnits;
 
     // Display objects
-    wxLabel   m_oLblName;
-    SpinCtrl  m_oSpnValue;
-    ChoUnits  m_oChoUnits;
-    wxLabel   m_oLblUnits;
+    wxLabel   m_oLblName;   // The static value name
+    SpinCtrl  m_oSpnValue;  // Displays the numeric value
+    ChoUnits  m_oChoUnits;  // Displayed if the units can change
+    wxLabel   m_oLblUnits;  // Displayed if the units do not change
 
     bool  bTempToDegC( float * pfValue );
     bool  bPhaseToDeg( float * pfValue );
 
     void  DoLayout( void );
 
-  public:
+  public :
 
     PnlValue( void );
    ~PnlValue( );
@@ -82,23 +82,27 @@ class PnlValue : public wxPanel
     bool  bSetIncSz    ( float fMinIncSz, float fMaxIncSz=-1.0 );
     bool  bSetParms    ( float fDefValue, float fMinValue, float fMaxValue,
                          float fMinIncSz=-1.0, float fMaxIncSz=-1.0 );
-    bool  bSetValue    ( int iValue, bool bNoUnits=FALSE )
-                            { return( bSetValue( (long) iValue, bNoUnits ) ); }
-    bool  bSetValue    ( long liValue, bool bNoUnits=FALSE );
+    bool  bSetValue    ( long   liValue, bool bNoUnits=FALSE );
+    bool  bSetValue    ( int     iValue, bool bNoUnits=FALSE )
+                          { return( bSetValue( (long)   iValue, bNoUnits ) ); }
     bool  bSetValue    ( double dfValue, bool bNoUnits=FALSE );
+    bool  bSetValue    ( float   fValue, bool bNoUnits=FALSE )
+                          { return( bSetValue( (double) fValue, bNoUnits ) ); }
     bool  bSetValue    ( const wxString & rosValue, bool bNoUnits=FALSE );
-    bool  bSetUnitsType( ChoUnits::eUnitsType eUType );
+    bool  bSetUnitsType( eUnitsType eUType );
     bool  bSetUnits    ( const wxString & rosUnits );
     bool  bSetDefValue ( float fValue )
                               { return( m_oSpnValue.bSetDefValue( fValue ) ); }
     bool  bSetDefUnits ( const wxString & rosUnits )
                             { return( m_oChoUnits.bSetDefUnits( rosUnits ) ); }
-                             
+
     bool  bShowUnits( bool bEnable );
 
     const wxString &  rosGetName ( void );
           long         liGetValue( void );
           double       dfGetValue( void );
+          int           iGetValue( void ) { return( (int)   liGetValue( ) ); }
+          float         fGetValue( void ) { return( (float) dfGetValue( ) ); }
     const wxString &  rosGetValue( void );
     const wxString &  rosGetUnits( void );
 
