@@ -2,7 +2,7 @@
 //                                  SpinCtrl.cpp                              *
 //                                 --------------                             *
 //  Started     : 20/03/2004                                                  *
-//  Last Update : 23/08/2007                                                  *
+//  Last Update : 09/06/2009                                                  *
 //  Copyright   : (C) 2004 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -231,8 +231,8 @@ bool  SpinCtrl::bSetValue( const wxString & rosValue )
 {
   double  fValue;
 
-  if( ! ConvertType::bStrToFlt( rosValue, &fValue ) ) return( FALSE );
-  if( ! bSetValue( (float) fValue ) )                 return( FALSE );
+  if( ! ConvertType::bStrToDFlt( rosValue, &fValue ) ) return( FALSE );
+  if( ! bSetValue( (float) fValue ) )                  return( FALSE );
 
   return( TRUE );
 }
@@ -356,7 +356,7 @@ bool  SpinCtrl::bSetParms( float fDefValue, float fMinValue, float fMaxValue,
   if( bIsCreated( ) )
   {
     os1 = m_oTxtValue.GetValue( );
-    ConvertType::bStrToFlt( os1, &df1 );
+    ConvertType::bStrToDFlt( os1, &df1 );
     if(      df1 < m_fMinValue ) bSetValue( m_fMinValue );
     else if( df1 > m_fMaxValue ) bSetValue( m_fMaxValue );
   }
@@ -400,11 +400,11 @@ float  SpinCtrl::fGetValue( void )
   double    df1;
 
   // Has the control been created?
-  if( ! bIsCreated( ) )                       return( -FLT_MAX );
+  if( ! bIsCreated( ) )                        return( -FLT_MAX );
 
   // Get the value as a float
   os1 = m_oTxtValue.GetValue( );
-  if( ! ConvertType::bStrToFlt( os1, &df1 ) ) return( -FLT_MAX );
+  if( ! ConvertType::bStrToDFlt( os1, &df1 ) ) return( -FLT_MAX );
 
   return( (float) df1 );
 }
@@ -511,8 +511,8 @@ void  SpinCtrl::OnSbnInc( wxSpinEvent & roEvtSpn )
   // Get the current text control value
   os1 = m_oTxtValue.GetValue( );
   df1 = 0.0;
-  if( ! ConvertType::bStrToFlt( os1, &df1 ) )     return;
-  if( ! ConvertType::bParseFlt( df1, &f1, &i1 ) ) return;
+  if( ! ConvertType::bStrToDFlt( os1, &df1 ) )     return;
+  if( ! ConvertType::bParseDFlt( df1, &f1, &i1 ) ) return;
   fValue = (float) df1;
 
   // Determine the increment size to use
@@ -548,7 +548,7 @@ void  SpinCtrl::OnSbnInc( wxSpinEvent & roEvtSpn )
 
   bSetValue( fValue );    // Set the text control value
 
-  roEvtSpn.Skip( true );  // Allow additional event handlers to be called
+  roEvtSpn.Skip( TRUE );  // Allow additional event handlers to be called
 }
 
 //*****************************************************************************
@@ -565,8 +565,8 @@ void  SpinCtrl::OnSbnDec( wxSpinEvent & roEvtSpn )
   int       i1;
 
   // Get the current text control value
-  if( ! ConvertType::bStrToFlt( m_oTxtValue.GetValue( ), &df1 ) ) return;
-  if( ! ConvertType::bParseFlt( df1, &f1, &i1 ) )                 return;
+  if( ! ConvertType::bStrToDFlt( m_oTxtValue.GetValue( ), &df1 ) ) return;
+  if( ! ConvertType::bParseDFlt( df1, &f1, &i1 ) )                 return;
   fValue = (float) df1;
 
   // Determine the decrement size to use
@@ -602,7 +602,7 @@ void  SpinCtrl::OnSbnDec( wxSpinEvent & roEvtSpn )
 
   bSetValue( fValue );    // Set the text control value
 
-  roEvtSpn.Skip( true );  // Allow additional event handlers to be called
+  roEvtSpn.Skip( TRUE );  // Allow additional event handlers to be called
 }
 
 //*****************************************************************************
