@@ -4,7 +4,7 @@
 //  Description : This class extends wxTextCtrl, it adds some useful          *
 //                functionality (eg. increment by more than one).             *
 //  Started     : 21/06/2004                                                  *
-//  Last Update : 25/10/2007                                                  *
+//  Last Update : 29/10/2008                                                  *
 //  Copyright   : (C) 2004 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -38,29 +38,30 @@
 
 // Local Constant Declarations
 
-#define  TXTCTL_INITMSG   wxT("Empty")
-#define  TXTCTL_DISPMIN      10    // Minimum allowable lines in display area
-#define  TXTCTL_DISPDEF      15    // Default number of lines in display area
-#define  TXTCTL_DISPMAX      50    // Maximum allowable lines in display area
-#define  TXTCTL_LINESMIN     50    // Minimum allowable lines in control
-#define  TXTCTL_LINESDEF   1000    // Default number of lines in control
-#define  TXTCTL_LINESMAX  10000    // Maximum allowable lines in control
-#define  TXTCTL_VIEWCOLS    122    // The number of columns in display area
-#define  TXTCTL_NBKTABHT     40    // Extra height in pixels needed by wxNotebook
-#define  TXTCTL_FONTHT       12.7  // Height in pixels of the font
+#define  TXTCTL_INITMSG    wxT("Empty")  // Default initialization message
+#define  TXTCTL_INITLINES  4      // Totals initial lines including init. msg.
+#define  TXTCTL_DISPMIN    10     // Minimum allowable lines in display area
+#define  TXTCTL_DISPDEF    15     // Default number of lines in display area
+#define  TXTCTL_DISPMAX    50     // Maximum allowable lines in display area
+#define  TXTCTL_LINESMIN   50     // Minimum allowable lines in control
+#define  TXTCTL_LINESDEF   1000   // Default number of lines in control
+#define  TXTCTL_LINESMAX   10000  // Maximum allowable lines in control
+#define  TXTCTL_VIEWCOLS   122    // The number of columns in display area
+#define  TXTCTL_NBKTABHT   40     // Extra height in pixels needed by wxNotebook
+#define  TXTCTL_FONTHT     12.7   // Height in pixels of the font
 
 //*****************************************************************************
 
 class TextCtrl : public wxTextCtrl
 {
-  private:
+  private :
 
             wxString  m_osInitMsg;
     static  int       m_iLinesMax; // Max no. lines the text controls will hold
     static  int       m_iLinesDsp; // No. of lines in text control display area
             int       m_iLinesCnt; // No. of lines currently in text control
 
-  public:
+  public :
 
     TextCtrl( void );
    ~TextCtrl( );
@@ -68,8 +69,9 @@ class TextCtrl : public wxTextCtrl
     bool  bCreate( wxWindow * poWin, wxWindowID oWinID=-1 );
     bool  bIsCreated( void ) { return( GetParent( )!=NULL ? TRUE : FALSE ); }
 
-    bool  bClear( void );
-    void  Initialize( void );
+    bool  bClear     ( void );
+    bool  bInitialize( void );
+    bool  bIsEmpty   ( void );
 
             bool  bSetInitMsg ( const wxString & rosMsg );
     static  bool  bSetLinesMax( int iLines );
